# Copyright 2013 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
This module contains APIs to facilitate Ucs backup and import
"""

import os
import platform
import time
import datetime
import logging
from ..ucsexception import UcsValidationException, UcsWarning

log = logging.getLogger('ucs')


def backup_ucs(handle, backup_type, file_dir, file_name, timeout_in_sec=600,
               preserve_pooled_values=False):
    """
    backup_ucs helps create and download Ucs backups.

    Args:
        handle (UcsHandle): Ucs Connection handle
        backup_type (str): type of backup
                        i.e. fullstate/config-logical/config-system/config-all
        file_dir (str): directory to download ucs backup file to
        file_name (str): name for the backup file
                         (supported file extension are '.tar.gz' and '.xml')
        timeout_in_sec (number) : time in seconds for which method waits
                              for the backUp file to generate before it exits.
        preserve_pooled_values (boolean): True/False,
                                            False - by default

    Example:
        file_dir = "/home/user/backup"\n
        file_name = "config_backup.xml"\n
        backup_ucs(handle, backup_type="config-logical",
                    file_dir=file_dir, file_name=file_name)\n
    """

    from ..mometa.mgmt.MgmtBackup import MgmtBackup, MgmtBackupConsts
    from ..mometa.top.TopSystem import TopSystem

    if not file_dir:
        raise UcsValidationException("Missing file_dir argument")
    if not file_name:
        raise UcsValidationException("Missing file_name argument")

    if backup_type is None:
        raise UcsValidationException("Missing backup_type argument")

    backup_types = ["config-all", "config-logical",
                    "config-system", "full-state"]

    if backup_type not in backup_types:
        raise UcsValidationException('Valid type values are %s'
                                     % ', '.join(backup_types))

    if not os.path.exists(file_dir):
        os.makedirs(file_dir)

    file_path = os.path.join(file_dir, file_name)

    # create MgmtBackup
    if backup_type in [MgmtBackupConsts.TYPE_FULL_STATE,
                       MgmtBackupConsts.TYPE_CONFIG_SYSTEM]:
        preserve_pooled_values = False

    host_name = platform.node().lower() \
        + datetime.datetime.now().strftime("%Y%m%d%H%M%S")

    top_system = TopSystem()
    mgmt_backup = MgmtBackup(parent_mo_or_dn=top_system,
                             hostname=host_name,
                             admin_state=MgmtBackupConsts.ADMIN_STATE_ENABLED,
                             proto=MgmtBackupConsts.PROTO_HTTP,
                             type=backup_type,
                             remote_file=file_path)

    if preserve_pooled_values:
        mgmt_backup.preserve_pooled_values = \
            MgmtBackupConsts.PRESERVE_POOLED_VALUES_YES
    else:
        mgmt_backup.preserve_pooled_values = \
            MgmtBackupConsts.PRESERVE_POOLED_VALUES_NO

    handle.add_mo(mgmt_backup)
    handle.commit()

    # Checking for the backup to compete.
    duration = timeout_in_sec
    poll_interval = 2

    while True:
        mgmt_backup = handle.query_dn(dn=mgmt_backup.dn)
        admin_state_temp = mgmt_backup.admin_state

        # Break condition:- if state id disabled then break
        if admin_state_temp == MgmtBackupConsts.ADMIN_STATE_DISABLED:
            break

        time.sleep(min(duration, poll_interval))
        duration = max(0, (duration - poll_interval))
        if duration == 0:
            handle.remove_mo(mgmt_backup)
            handle.commit()
            raise UcsValidationException('backup_ucs timed out')

    # download backup
    file_source = "backupfile/" + file_name
    try:
        handle.file_download(url_suffix=file_source,
                             file_dir=file_dir,
                             file_name=file_name)
    except Exception as err:
        UcsWarning("Download Error.....")
        UcsWarning(str(err))

    # remove backup from ucs
    handle.remove_mo(mgmt_backup)
    handle.commit()


def import_ucs_backup(handle, file_dir, file_name, merge=False):
    """
    This operation uploads a Ucs backup taken earlier via GUI
    or backup_ucs operation for all configuration, system configuration,
    and logical configuration files. User can perform an import while the
    system is up and running.

    Args:
        handle (UcsHandle): connection handle
        file_dir (str): directory containing ucs backup file
        file_name (str): backup file name to be imported
        merge (boolean): True/False, specifies whether to merge the backup
                        configuration with the existing UCSM configuration

    Example:
        file_dir = "/home/user/backup"\n
        file_name = "config_backup.xml"\n
        import_ucs_backup(handle, file_dir=file_dir, file_name=file_name)\n
        import_ucs_backup(handle, file_dir=file_dir, file_name=file_name,
                        merge=True)\n
    """

    from ..mometa.top.TopSystem import TopSystem
    from ..mometa.mgmt.MgmtImporter import MgmtImporter, MgmtImporterConsts

    if not file_dir:
        raise UcsValidationException("Missing file_dir argument")
    if not file_name:
        raise UcsValidationException("Missing file_name argument")

    file_path = os.path.join(file_dir, file_name)
    log.debug(file_path)
    if not os.path.exists(file_path):
        raise UcsValidationException("Backup File not found <%s>" %
                                     file_path)

    # create MgmtImporter
    # host_name = os.environ['COMPUTERNAME'].lower() + \
    #             datetime.datetime.now().strftime('%Y%m%d%H%M')
    host_name = "backup." + str(datetime.datetime.now().strftime('%Y%m%d%H%M'))

    top_system = TopSystem()
    mgmt_importer = MgmtImporter(
        parent_mo_or_dn=top_system,
        hostname=host_name,
        remote_file=file_path,
        proto=MgmtImporterConsts.PROTO_HTTP,
        admin_state=MgmtImporterConsts.ADMIN_STATE_ENABLED)

    if merge:
        mgmt_importer.action = MgmtImporterConsts.ACTION_MERGE
    else:
        mgmt_importer.action = MgmtImporterConsts.ACTION_REPLACE

    uri_suffix = "operations/file-%s/importconfig.txt" % file_name
    handle.file_upload(url_suffix=uri_suffix,
                       file_dir=file_dir,
                       file_name=file_name)

    handle.add_mo(mgmt_importer)
    handle.commit()

    return mgmt_importer



"""This module contains the meta information of StatsSubscribe ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("StatsSubscribe", "statsSubscribe", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_category": MethodPropertyMeta("InCategory", "inCategory", "Xs:string", "Version142b", "Input", False),
    "in_provider": MethodPropertyMeta("InProvider", "inProvider", "Xs:string", "Version142b", "Input", False),
    "in_schema_info": MethodPropertyMeta("InSchemaInfo", "inSchemaInfo", "ConfigSet", "Version142b", "Input", True),
    "in_time_interval": MethodPropertyMeta("InTimeInterval", "inTimeInterval", "Xs:string", "Version142b", "Input", False),
}

prop_map = {
    "cookie": "cookie",
    "inCategory": "in_category",
    "inProvider": "in_provider",
    "inSchemaInfo": "in_schema_info",
    "inTimeInterval": "in_time_interval",
}



"""This module contains the general information for BiosVfUSBPortConfiguration ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class BiosVfUSBPortConfigurationConsts:
    SUPPORTED_BY_DEFAULT_NO = "no"
    SUPPORTED_BY_DEFAULT_YES = "yes"
    VP_PORT6064_EMULATION_DISABLED = "disabled"
    VP_PORT6064_EMULATION_ENABLED = "enabled"
    VP_PORT6064_EMULATION_PLATFORM_DEFAULT = "platform-default"
    VP_PORT6064_EMULATION_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_USBPORT_FRONT_DISABLED = "disabled"
    VP_USBPORT_FRONT_ENABLED = "enabled"
    VP_USBPORT_FRONT_PLATFORM_DEFAULT = "platform-default"
    VP_USBPORT_FRONT_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_USBPORT_INTERNAL_DISABLED = "disabled"
    VP_USBPORT_INTERNAL_ENABLED = "enabled"
    VP_USBPORT_INTERNAL_PLATFORM_DEFAULT = "platform-default"
    VP_USBPORT_INTERNAL_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_USBPORT_KVM_DISABLED = "disabled"
    VP_USBPORT_KVM_ENABLED = "enabled"
    VP_USBPORT_KVM_PLATFORM_DEFAULT = "platform-default"
    VP_USBPORT_KVM_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_USBPORT_REAR_DISABLED = "disabled"
    VP_USBPORT_REAR_ENABLED = "enabled"
    VP_USBPORT_REAR_PLATFORM_DEFAULT = "platform-default"
    VP_USBPORT_REAR_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_USBPORT_SDCARD_DISABLED = "disabled"
    VP_USBPORT_SDCARD_ENABLED = "enabled"
    VP_USBPORT_SDCARD_PLATFORM_DEFAULT = "platform-default"
    VP_USBPORT_SDCARD_PLATFORM_RECOMMENDED = "platform-recommended"
    VP_USBPORT_VMEDIA_DISABLED = "disabled"
    VP_USBPORT_VMEDIA_ENABLED = "enabled"
    VP_USBPORT_VMEDIA_PLATFORM_DEFAULT = "platform-default"
    VP_USBPORT_VMEDIA_PLATFORM_RECOMMENDED = "platform-recommended"


class BiosVfUSBPortConfiguration(ManagedObject):
    """This is BiosVfUSBPortConfiguration class."""

    consts = BiosVfUSBPortConfigurationConsts()
    naming_props = set([])

    mo_meta = MoMeta("BiosVfUSBPortConfiguration", "biosVfUSBPortConfiguration", "USB-port-configuration", VersionMeta.Version222c, "InputOutput", 0xfff, [], ["admin", "ls-compute", "ls-config", "ls-server", "ls-server-policy", "pn-policy"], ['biosSettings', 'biosVProfile'], [], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version222c, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version222c, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "prop_acl": MoPropertyMeta("prop_acl", "propAcl", "ulong", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version222c, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version222c, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "supported_by_default": MoPropertyMeta("supported_by_default", "supportedByDefault", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["no", "yes"], []),
        "vp_port6064_emulation": MoPropertyMeta("vp_port6064_emulation", "vpPort6064Emulation", "string", VersionMeta.Version222c, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["disabled", "enabled", "platform-default", "platform-recommended"], []),
        "vp_usb_port_front": MoPropertyMeta("vp_usb_port_front", "vpUSBPortFront", "string", VersionMeta.Version222c, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["disabled", "enabled", "platform-default", "platform-recommended"], []),
        "vp_usb_port_internal": MoPropertyMeta("vp_usb_port_internal", "vpUSBPortInternal", "string", VersionMeta.Version222c, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["disabled", "enabled", "platform-default", "platform-recommended"], []),
        "vp_usb_port_kvm": MoPropertyMeta("vp_usb_port_kvm", "vpUSBPortKVM", "string", VersionMeta.Version222c, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, ["disabled", "enabled", "platform-default", "platform-recommended"], []),
        "vp_usb_port_rear": MoPropertyMeta("vp_usb_port_rear", "vpUSBPortRear", "string", VersionMeta.Version222c, MoPropertyMeta.READ_WRITE, 0x200, None, None, None, ["disabled", "enabled", "platform-default", "platform-recommended"], []),
        "vp_usb_port_sd_card": MoPropertyMeta("vp_usb_port_sd_card", "vpUSBPortSDCard", "string", VersionMeta.Version222c, MoPropertyMeta.READ_WRITE, 0x400, None, None, None, ["disabled", "enabled", "platform-default", "platform-recommended"], []),
        "vp_usb_port_v_media": MoPropertyMeta("vp_usb_port_v_media", "vpUSBPortVMedia", "string", VersionMeta.Version222c, MoPropertyMeta.READ_WRITE, 0x800, None, None, None, ["disabled", "enabled", "platform-default", "platform-recommended"], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "propAcl": "prop_acl", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "supportedByDefault": "supported_by_default", 
        "vpPort6064Emulation": "vp_port6064_emulation", 
        "vpUSBPortFront": "vp_usb_port_front", 
        "vpUSBPortInternal": "vp_usb_port_internal", 
        "vpUSBPortKVM": "vp_usb_port_kvm", 
        "vpUSBPortRear": "vp_usb_port_rear", 
        "vpUSBPortSDCard": "vp_usb_port_sd_card", 
        "vpUSBPortVMedia": "vp_usb_port_v_media", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.prop_acl = None
        self.sacl = None
        self.status = None
        self.supported_by_default = None
        self.vp_port6064_emulation = None
        self.vp_usb_port_front = None
        self.vp_usb_port_internal = None
        self.vp_usb_port_kvm = None
        self.vp_usb_port_rear = None
        self.vp_usb_port_sd_card = None
        self.vp_usb_port_v_media = None

        ManagedObject.__init__(self, "BiosVfUSBPortConfiguration", parent_mo_or_dn, **kwargs)



"""This module contains the general information for ProcessorIOStats ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ProcessorIOStatsConsts:
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class ProcessorIOStats(ManagedObject):
    """This is ProcessorIOStats class."""

    consts = ProcessorIOStatsConsts()
    naming_props = set([])

    mo_meta = MoMeta("ProcessorIOStats", "processorIOStats", "io-stats", VersionMeta.Version412a, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], ['processorUnit'], [], [None])

    prop_meta = {
        "pc_ie_bank_correctable_errors": MoPropertyMeta("pc_ie_bank_correctable_errors", "PCIeBankCorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_correctable_errors15_min": MoPropertyMeta("pc_ie_bank_correctable_errors15_min", "PCIeBankCorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_correctable_errors15_min_h": MoPropertyMeta("pc_ie_bank_correctable_errors15_min_h", "PCIeBankCorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_correctable_errors1_day": MoPropertyMeta("pc_ie_bank_correctable_errors1_day", "PCIeBankCorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_correctable_errors1_day_h": MoPropertyMeta("pc_ie_bank_correctable_errors1_day_h", "PCIeBankCorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_correctable_errors1_hour": MoPropertyMeta("pc_ie_bank_correctable_errors1_hour", "PCIeBankCorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_correctable_errors1_hour_h": MoPropertyMeta("pc_ie_bank_correctable_errors1_hour_h", "PCIeBankCorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_correctable_errors1_week": MoPropertyMeta("pc_ie_bank_correctable_errors1_week", "PCIeBankCorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_correctable_errors1_week_h": MoPropertyMeta("pc_ie_bank_correctable_errors1_week_h", "PCIeBankCorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_correctable_errors2_weeks": MoPropertyMeta("pc_ie_bank_correctable_errors2_weeks", "PCIeBankCorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_correctable_errors2_weeks_h": MoPropertyMeta("pc_ie_bank_correctable_errors2_weeks_h", "PCIeBankCorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_uncorrectable_errors": MoPropertyMeta("pc_ie_bank_uncorrectable_errors", "PCIeBankUncorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_uncorrectable_errors15_min": MoPropertyMeta("pc_ie_bank_uncorrectable_errors15_min", "PCIeBankUncorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_uncorrectable_errors15_min_h": MoPropertyMeta("pc_ie_bank_uncorrectable_errors15_min_h", "PCIeBankUncorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_uncorrectable_errors1_day": MoPropertyMeta("pc_ie_bank_uncorrectable_errors1_day", "PCIeBankUncorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_uncorrectable_errors1_day_h": MoPropertyMeta("pc_ie_bank_uncorrectable_errors1_day_h", "PCIeBankUncorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_uncorrectable_errors1_hour": MoPropertyMeta("pc_ie_bank_uncorrectable_errors1_hour", "PCIeBankUncorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_uncorrectable_errors1_hour_h": MoPropertyMeta("pc_ie_bank_uncorrectable_errors1_hour_h", "PCIeBankUncorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_uncorrectable_errors1_week": MoPropertyMeta("pc_ie_bank_uncorrectable_errors1_week", "PCIeBankUncorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_uncorrectable_errors1_week_h": MoPropertyMeta("pc_ie_bank_uncorrectable_errors1_week_h", "PCIeBankUncorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_uncorrectable_errors2_weeks": MoPropertyMeta("pc_ie_bank_uncorrectable_errors2_weeks", "PCIeBankUncorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "pc_ie_bank_uncorrectable_errors2_weeks_h": MoPropertyMeta("pc_ie_bank_uncorrectable_errors2_weeks_h", "PCIeBankUncorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sata_uncorrectable_errors": MoPropertyMeta("sata_uncorrectable_errors", "SATAUncorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sata_uncorrectable_errors15_min": MoPropertyMeta("sata_uncorrectable_errors15_min", "SATAUncorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sata_uncorrectable_errors15_min_h": MoPropertyMeta("sata_uncorrectable_errors15_min_h", "SATAUncorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sata_uncorrectable_errors1_day": MoPropertyMeta("sata_uncorrectable_errors1_day", "SATAUncorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sata_uncorrectable_errors1_day_h": MoPropertyMeta("sata_uncorrectable_errors1_day_h", "SATAUncorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sata_uncorrectable_errors1_hour": MoPropertyMeta("sata_uncorrectable_errors1_hour", "SATAUncorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sata_uncorrectable_errors1_hour_h": MoPropertyMeta("sata_uncorrectable_errors1_hour_h", "SATAUncorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sata_uncorrectable_errors1_week": MoPropertyMeta("sata_uncorrectable_errors1_week", "SATAUncorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sata_uncorrectable_errors1_week_h": MoPropertyMeta("sata_uncorrectable_errors1_week_h", "SATAUncorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sata_uncorrectable_errors2_weeks": MoPropertyMeta("sata_uncorrectable_errors2_weeks", "SATAUncorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sata_uncorrectable_errors2_weeks_h": MoPropertyMeta("sata_uncorrectable_errors2_weeks_h", "SATAUncorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sat_acorrectable_errors": MoPropertyMeta("sat_acorrectable_errors", "SATAcorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sat_acorrectable_errors15_min": MoPropertyMeta("sat_acorrectable_errors15_min", "SATAcorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sat_acorrectable_errors15_min_h": MoPropertyMeta("sat_acorrectable_errors15_min_h", "SATAcorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sat_acorrectable_errors1_day": MoPropertyMeta("sat_acorrectable_errors1_day", "SATAcorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sat_acorrectable_errors1_day_h": MoPropertyMeta("sat_acorrectable_errors1_day_h", "SATAcorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sat_acorrectable_errors1_hour": MoPropertyMeta("sat_acorrectable_errors1_hour", "SATAcorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sat_acorrectable_errors1_hour_h": MoPropertyMeta("sat_acorrectable_errors1_hour_h", "SATAcorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sat_acorrectable_errors1_week": MoPropertyMeta("sat_acorrectable_errors1_week", "SATAcorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sat_acorrectable_errors1_week_h": MoPropertyMeta("sat_acorrectable_errors1_week_h", "SATAcorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sat_acorrectable_errors2_weeks": MoPropertyMeta("sat_acorrectable_errors2_weeks", "SATAcorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sat_acorrectable_errors2_weeks_h": MoPropertyMeta("sat_acorrectable_errors2_weeks_h", "SATAcorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "smn_uncorrectable_errors": MoPropertyMeta("smn_uncorrectable_errors", "SMNUncorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "smn_uncorrectable_errors15_min": MoPropertyMeta("smn_uncorrectable_errors15_min", "SMNUncorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "smn_uncorrectable_errors15_min_h": MoPropertyMeta("smn_uncorrectable_errors15_min_h", "SMNUncorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "smn_uncorrectable_errors1_day": MoPropertyMeta("smn_uncorrectable_errors1_day", "SMNUncorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "smn_uncorrectable_errors1_day_h": MoPropertyMeta("smn_uncorrectable_errors1_day_h", "SMNUncorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "smn_uncorrectable_errors1_hour": MoPropertyMeta("smn_uncorrectable_errors1_hour", "SMNUncorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "smn_uncorrectable_errors1_hour_h": MoPropertyMeta("smn_uncorrectable_errors1_hour_h", "SMNUncorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "smn_uncorrectable_errors1_week": MoPropertyMeta("smn_uncorrectable_errors1_week", "SMNUncorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "smn_uncorrectable_errors1_week_h": MoPropertyMeta("smn_uncorrectable_errors1_week_h", "SMNUncorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "smn_uncorrectable_errors2_weeks": MoPropertyMeta("smn_uncorrectable_errors2_weeks", "SMNUncorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "smn_uncorrectable_errors2_weeks_h": MoPropertyMeta("smn_uncorrectable_errors2_weeks_h", "SMNUncorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sm_ncorrectable_errors": MoPropertyMeta("sm_ncorrectable_errors", "SMNcorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sm_ncorrectable_errors15_min": MoPropertyMeta("sm_ncorrectable_errors15_min", "SMNcorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sm_ncorrectable_errors15_min_h": MoPropertyMeta("sm_ncorrectable_errors15_min_h", "SMNcorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sm_ncorrectable_errors1_day": MoPropertyMeta("sm_ncorrectable_errors1_day", "SMNcorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sm_ncorrectable_errors1_day_h": MoPropertyMeta("sm_ncorrectable_errors1_day_h", "SMNcorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sm_ncorrectable_errors1_hour": MoPropertyMeta("sm_ncorrectable_errors1_hour", "SMNcorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sm_ncorrectable_errors1_hour_h": MoPropertyMeta("sm_ncorrectable_errors1_hour_h", "SMNcorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sm_ncorrectable_errors1_week": MoPropertyMeta("sm_ncorrectable_errors1_week", "SMNcorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sm_ncorrectable_errors1_week_h": MoPropertyMeta("sm_ncorrectable_errors1_week_h", "SMNcorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sm_ncorrectable_errors2_weeks": MoPropertyMeta("sm_ncorrectable_errors2_weeks", "SMNcorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "sm_ncorrectable_errors2_weeks_h": MoPropertyMeta("sm_ncorrectable_errors2_weeks_h", "SMNcorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "usb_uncorrectable_errors": MoPropertyMeta("usb_uncorrectable_errors", "USBUncorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "usb_uncorrectable_errors15_min": MoPropertyMeta("usb_uncorrectable_errors15_min", "USBUncorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "usb_uncorrectable_errors15_min_h": MoPropertyMeta("usb_uncorrectable_errors15_min_h", "USBUncorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "usb_uncorrectable_errors1_day": MoPropertyMeta("usb_uncorrectable_errors1_day", "USBUncorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "usb_uncorrectable_errors1_day_h": MoPropertyMeta("usb_uncorrectable_errors1_day_h", "USBUncorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "usb_uncorrectable_errors1_hour": MoPropertyMeta("usb_uncorrectable_errors1_hour", "USBUncorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "usb_uncorrectable_errors1_hour_h": MoPropertyMeta("usb_uncorrectable_errors1_hour_h", "USBUncorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "usb_uncorrectable_errors1_week": MoPropertyMeta("usb_uncorrectable_errors1_week", "USBUncorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "usb_uncorrectable_errors1_week_h": MoPropertyMeta("usb_uncorrectable_errors1_week_h", "USBUncorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "usb_uncorrectable_errors2_weeks": MoPropertyMeta("usb_uncorrectable_errors2_weeks", "USBUncorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "usb_uncorrectable_errors2_weeks_h": MoPropertyMeta("usb_uncorrectable_errors2_weeks_h", "USBUncorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "us_bcorrectable_errors": MoPropertyMeta("us_bcorrectable_errors", "USBcorrectableErrors", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "us_bcorrectable_errors15_min": MoPropertyMeta("us_bcorrectable_errors15_min", "USBcorrectableErrors15Min", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "us_bcorrectable_errors15_min_h": MoPropertyMeta("us_bcorrectable_errors15_min_h", "USBcorrectableErrors15MinH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "us_bcorrectable_errors1_day": MoPropertyMeta("us_bcorrectable_errors1_day", "USBcorrectableErrors1Day", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "us_bcorrectable_errors1_day_h": MoPropertyMeta("us_bcorrectable_errors1_day_h", "USBcorrectableErrors1DayH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "us_bcorrectable_errors1_hour": MoPropertyMeta("us_bcorrectable_errors1_hour", "USBcorrectableErrors1Hour", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "us_bcorrectable_errors1_hour_h": MoPropertyMeta("us_bcorrectable_errors1_hour_h", "USBcorrectableErrors1HourH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "us_bcorrectable_errors1_week": MoPropertyMeta("us_bcorrectable_errors1_week", "USBcorrectableErrors1Week", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "us_bcorrectable_errors1_week_h": MoPropertyMeta("us_bcorrectable_errors1_week_h", "USBcorrectableErrors1WeekH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "us_bcorrectable_errors2_weeks": MoPropertyMeta("us_bcorrectable_errors2_weeks", "USBcorrectableErrors2Weeks", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "us_bcorrectable_errors2_weeks_h": MoPropertyMeta("us_bcorrectable_errors2_weeks_h", "USBcorrectableErrors2WeeksH", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version412a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version412a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version412a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
    }

    prop_map = {
        "PCIeBankCorrectableErrors": "pc_ie_bank_correctable_errors", 
        "PCIeBankCorrectableErrors15Min": "pc_ie_bank_correctable_errors15_min", 
        "PCIeBankCorrectableErrors15MinH": "pc_ie_bank_correctable_errors15_min_h", 
        "PCIeBankCorrectableErrors1Day": "pc_ie_bank_correctable_errors1_day", 
        "PCIeBankCorrectableErrors1DayH": "pc_ie_bank_correctable_errors1_day_h", 
        "PCIeBankCorrectableErrors1Hour": "pc_ie_bank_correctable_errors1_hour", 
        "PCIeBankCorrectableErrors1HourH": "pc_ie_bank_correctable_errors1_hour_h", 
        "PCIeBankCorrectableErrors1Week": "pc_ie_bank_correctable_errors1_week", 
        "PCIeBankCorrectableErrors1WeekH": "pc_ie_bank_correctable_errors1_week_h", 
        "PCIeBankCorrectableErrors2Weeks": "pc_ie_bank_correctable_errors2_weeks", 
        "PCIeBankCorrectableErrors2WeeksH": "pc_ie_bank_correctable_errors2_weeks_h", 
        "PCIeBankUncorrectableErrors": "pc_ie_bank_uncorrectable_errors", 
        "PCIeBankUncorrectableErrors15Min": "pc_ie_bank_uncorrectable_errors15_min", 
        "PCIeBankUncorrectableErrors15MinH": "pc_ie_bank_uncorrectable_errors15_min_h", 
        "PCIeBankUncorrectableErrors1Day": "pc_ie_bank_uncorrectable_errors1_day", 
        "PCIeBankUncorrectableErrors1DayH": "pc_ie_bank_uncorrectable_errors1_day_h", 
        "PCIeBankUncorrectableErrors1Hour": "pc_ie_bank_uncorrectable_errors1_hour", 
        "PCIeBankUncorrectableErrors1HourH": "pc_ie_bank_uncorrectable_errors1_hour_h", 
        "PCIeBankUncorrectableErrors1Week": "pc_ie_bank_uncorrectable_errors1_week", 
        "PCIeBankUncorrectableErrors1WeekH": "pc_ie_bank_uncorrectable_errors1_week_h", 
        "PCIeBankUncorrectableErrors2Weeks": "pc_ie_bank_uncorrectable_errors2_weeks", 
        "PCIeBankUncorrectableErrors2WeeksH": "pc_ie_bank_uncorrectable_errors2_weeks_h", 
        "SATAUncorrectableErrors": "sata_uncorrectable_errors", 
        "SATAUncorrectableErrors15Min": "sata_uncorrectable_errors15_min", 
        "SATAUncorrectableErrors15MinH": "sata_uncorrectable_errors15_min_h", 
        "SATAUncorrectableErrors1Day": "sata_uncorrectable_errors1_day", 
        "SATAUncorrectableErrors1DayH": "sata_uncorrectable_errors1_day_h", 
        "SATAUncorrectableErrors1Hour": "sata_uncorrectable_errors1_hour", 
        "SATAUncorrectableErrors1HourH": "sata_uncorrectable_errors1_hour_h", 
        "SATAUncorrectableErrors1Week": "sata_uncorrectable_errors1_week", 
        "SATAUncorrectableErrors1WeekH": "sata_uncorrectable_errors1_week_h", 
        "SATAUncorrectableErrors2Weeks": "sata_uncorrectable_errors2_weeks", 
        "SATAUncorrectableErrors2WeeksH": "sata_uncorrectable_errors2_weeks_h", 
        "SATAcorrectableErrors": "sat_acorrectable_errors", 
        "SATAcorrectableErrors15Min": "sat_acorrectable_errors15_min", 
        "SATAcorrectableErrors15MinH": "sat_acorrectable_errors15_min_h", 
        "SATAcorrectableErrors1Day": "sat_acorrectable_errors1_day", 
        "SATAcorrectableErrors1DayH": "sat_acorrectable_errors1_day_h", 
        "SATAcorrectableErrors1Hour": "sat_acorrectable_errors1_hour", 
        "SATAcorrectableErrors1HourH": "sat_acorrectable_errors1_hour_h", 
        "SATAcorrectableErrors1Week": "sat_acorrectable_errors1_week", 
        "SATAcorrectableErrors1WeekH": "sat_acorrectable_errors1_week_h", 
        "SATAcorrectableErrors2Weeks": "sat_acorrectable_errors2_weeks", 
        "SATAcorrectableErrors2WeeksH": "sat_acorrectable_errors2_weeks_h", 
        "SMNUncorrectableErrors": "smn_uncorrectable_errors", 
        "SMNUncorrectableErrors15Min": "smn_uncorrectable_errors15_min", 
        "SMNUncorrectableErrors15MinH": "smn_uncorrectable_errors15_min_h", 
        "SMNUncorrectableErrors1Day": "smn_uncorrectable_errors1_day", 
        "SMNUncorrectableErrors1DayH": "smn_uncorrectable_errors1_day_h", 
        "SMNUncorrectableErrors1Hour": "smn_uncorrectable_errors1_hour", 
        "SMNUncorrectableErrors1HourH": "smn_uncorrectable_errors1_hour_h", 
        "SMNUncorrectableErrors1Week": "smn_uncorrectable_errors1_week", 
        "SMNUncorrectableErrors1WeekH": "smn_uncorrectable_errors1_week_h", 
        "SMNUncorrectableErrors2Weeks": "smn_uncorrectable_errors2_weeks", 
        "SMNUncorrectableErrors2WeeksH": "smn_uncorrectable_errors2_weeks_h", 
        "SMNcorrectableErrors": "sm_ncorrectable_errors", 
        "SMNcorrectableErrors15Min": "sm_ncorrectable_errors15_min", 
        "SMNcorrectableErrors15MinH": "sm_ncorrectable_errors15_min_h", 
        "SMNcorrectableErrors1Day": "sm_ncorrectable_errors1_day", 
        "SMNcorrectableErrors1DayH": "sm_ncorrectable_errors1_day_h", 
        "SMNcorrectableErrors1Hour": "sm_ncorrectable_errors1_hour", 
        "SMNcorrectableErrors1HourH": "sm_ncorrectable_errors1_hour_h", 
        "SMNcorrectableErrors1Week": "sm_ncorrectable_errors1_week", 
        "SMNcorrectableErrors1WeekH": "sm_ncorrectable_errors1_week_h", 
        "SMNcorrectableErrors2Weeks": "sm_ncorrectable_errors2_weeks", 
        "SMNcorrectableErrors2WeeksH": "sm_ncorrectable_errors2_weeks_h", 
        "USBUncorrectableErrors": "usb_uncorrectable_errors", 
        "USBUncorrectableErrors15Min": "usb_uncorrectable_errors15_min", 
        "USBUncorrectableErrors15MinH": "usb_uncorrectable_errors15_min_h", 
        "USBUncorrectableErrors1Day": "usb_uncorrectable_errors1_day", 
        "USBUncorrectableErrors1DayH": "usb_uncorrectable_errors1_day_h", 
        "USBUncorrectableErrors1Hour": "usb_uncorrectable_errors1_hour", 
        "USBUncorrectableErrors1HourH": "usb_uncorrectable_errors1_hour_h", 
        "USBUncorrectableErrors1Week": "usb_uncorrectable_errors1_week", 
        "USBUncorrectableErrors1WeekH": "usb_uncorrectable_errors1_week_h", 
        "USBUncorrectableErrors2Weeks": "usb_uncorrectable_errors2_weeks", 
        "USBUncorrectableErrors2WeeksH": "usb_uncorrectable_errors2_weeks_h", 
        "USBcorrectableErrors": "us_bcorrectable_errors", 
        "USBcorrectableErrors15Min": "us_bcorrectable_errors15_min", 
        "USBcorrectableErrors15MinH": "us_bcorrectable_errors15_min_h", 
        "USBcorrectableErrors1Day": "us_bcorrectable_errors1_day", 
        "USBcorrectableErrors1DayH": "us_bcorrectable_errors1_day_h", 
        "USBcorrectableErrors1Hour": "us_bcorrectable_errors1_hour", 
        "USBcorrectableErrors1HourH": "us_bcorrectable_errors1_hour_h", 
        "USBcorrectableErrors1Week": "us_bcorrectable_errors1_week", 
        "USBcorrectableErrors1WeekH": "us_bcorrectable_errors1_week_h", 
        "USBcorrectableErrors2Weeks": "us_bcorrectable_errors2_weeks", 
        "USBcorrectableErrors2WeeksH": "us_bcorrectable_errors2_weeks_h", 
        "childAction": "child_action", 
        "dn": "dn", 
        "intervals": "intervals", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.pc_ie_bank_correctable_errors = None
        self.pc_ie_bank_correctable_errors15_min = None
        self.pc_ie_bank_correctable_errors15_min_h = None
        self.pc_ie_bank_correctable_errors1_day = None
        self.pc_ie_bank_correctable_errors1_day_h = None
        self.pc_ie_bank_correctable_errors1_hour = None
        self.pc_ie_bank_correctable_errors1_hour_h = None
        self.pc_ie_bank_correctable_errors1_week = None
        self.pc_ie_bank_correctable_errors1_week_h = None
        self.pc_ie_bank_correctable_errors2_weeks = None
        self.pc_ie_bank_correctable_errors2_weeks_h = None
        self.pc_ie_bank_uncorrectable_errors = None
        self.pc_ie_bank_uncorrectable_errors15_min = None
        self.pc_ie_bank_uncorrectable_errors15_min_h = None
        self.pc_ie_bank_uncorrectable_errors1_day = None
        self.pc_ie_bank_uncorrectable_errors1_day_h = None
        self.pc_ie_bank_uncorrectable_errors1_hour = None
        self.pc_ie_bank_uncorrectable_errors1_hour_h = None
        self.pc_ie_bank_uncorrectable_errors1_week = None
        self.pc_ie_bank_uncorrectable_errors1_week_h = None
        self.pc_ie_bank_uncorrectable_errors2_weeks = None
        self.pc_ie_bank_uncorrectable_errors2_weeks_h = None
        self.sata_uncorrectable_errors = None
        self.sata_uncorrectable_errors15_min = None
        self.sata_uncorrectable_errors15_min_h = None
        self.sata_uncorrectable_errors1_day = None
        self.sata_uncorrectable_errors1_day_h = None
        self.sata_uncorrectable_errors1_hour = None
        self.sata_uncorrectable_errors1_hour_h = None
        self.sata_uncorrectable_errors1_week = None
        self.sata_uncorrectable_errors1_week_h = None
        self.sata_uncorrectable_errors2_weeks = None
        self.sata_uncorrectable_errors2_weeks_h = None
        self.sat_acorrectable_errors = None
        self.sat_acorrectable_errors15_min = None
        self.sat_acorrectable_errors15_min_h = None
        self.sat_acorrectable_errors1_day = None
        self.sat_acorrectable_errors1_day_h = None
        self.sat_acorrectable_errors1_hour = None
        self.sat_acorrectable_errors1_hour_h = None
        self.sat_acorrectable_errors1_week = None
        self.sat_acorrectable_errors1_week_h = None
        self.sat_acorrectable_errors2_weeks = None
        self.sat_acorrectable_errors2_weeks_h = None
        self.smn_uncorrectable_errors = None
        self.smn_uncorrectable_errors15_min = None
        self.smn_uncorrectable_errors15_min_h = None
        self.smn_uncorrectable_errors1_day = None
        self.smn_uncorrectable_errors1_day_h = None
        self.smn_uncorrectable_errors1_hour = None
        self.smn_uncorrectable_errors1_hour_h = None
        self.smn_uncorrectable_errors1_week = None
        self.smn_uncorrectable_errors1_week_h = None
        self.smn_uncorrectable_errors2_weeks = None
        self.smn_uncorrectable_errors2_weeks_h = None
        self.sm_ncorrectable_errors = None
        self.sm_ncorrectable_errors15_min = None
        self.sm_ncorrectable_errors15_min_h = None
        self.sm_ncorrectable_errors1_day = None
        self.sm_ncorrectable_errors1_day_h = None
        self.sm_ncorrectable_errors1_hour = None
        self.sm_ncorrectable_errors1_hour_h = None
        self.sm_ncorrectable_errors1_week = None
        self.sm_ncorrectable_errors1_week_h = None
        self.sm_ncorrectable_errors2_weeks = None
        self.sm_ncorrectable_errors2_weeks_h = None
        self.usb_uncorrectable_errors = None
        self.usb_uncorrectable_errors15_min = None
        self.usb_uncorrectable_errors15_min_h = None
        self.usb_uncorrectable_errors1_day = None
        self.usb_uncorrectable_errors1_day_h = None
        self.usb_uncorrectable_errors1_hour = None
        self.usb_uncorrectable_errors1_hour_h = None
        self.usb_uncorrectable_errors1_week = None
        self.usb_uncorrectable_errors1_week_h = None
        self.usb_uncorrectable_errors2_weeks = None
        self.usb_uncorrectable_errors2_weeks_h = None
        self.us_bcorrectable_errors = None
        self.us_bcorrectable_errors15_min = None
        self.us_bcorrectable_errors15_min_h = None
        self.us_bcorrectable_errors1_day = None
        self.us_bcorrectable_errors1_day_h = None
        self.us_bcorrectable_errors1_hour = None
        self.us_bcorrectable_errors1_hour_h = None
        self.us_bcorrectable_errors1_week = None
        self.us_bcorrectable_errors1_week_h = None
        self.us_bcorrectable_errors2_weeks = None
        self.us_bcorrectable_errors2_weeks_h = None
        self.child_action = None
        self.intervals = None
        self.sacl = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.update = None

        ManagedObject.__init__(self, "ProcessorIOStats", parent_mo_or_dn, **kwargs)



"""This module contains the general information for EtherPIoEndPoint ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class EtherPIoEndPointConsts:
    EP_CLOUD_TYPE_LAN = "lan"
    EP_CLOUD_TYPE_SAN = "san"
    EP_CLOUD_TYPE_UNCLASSIFIED = "unclassified"


class EtherPIoEndPoint(ManagedObject):
    """This is EtherPIoEndPoint class."""

    consts = EtherPIoEndPointConsts()
    naming_props = set(['epCloudType'])

    mo_meta = MoMeta("EtherPIoEndPoint", "etherPIoEndPoint", "EndPointDn-cloud-[ep_cloud_type]", VersionMeta.Version211a, "InputOutput", 0x7f, [], ["read-only"], ['etherPIo'], [], [None])

    prop_meta = {
        "end_point_dn": MoPropertyMeta("end_point_dn", "EndPointDn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version211a, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "ep_cloud_type": MoPropertyMeta("ep_cloud_type", "epCloudType", "string", VersionMeta.Version211a, MoPropertyMeta.NAMING, 0x8, None, None, None, ["lan", "san", "unclassified"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "usr_lbl": MoPropertyMeta("usr_lbl", "usrLbl", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,32}""", [], []),
    }

    prop_map = {
        "EndPointDn": "end_point_dn", 
        "childAction": "child_action", 
        "dn": "dn", 
        "epCloudType": "ep_cloud_type", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "usrLbl": "usr_lbl", 
    }

    def __init__(self, parent_mo_or_dn, ep_cloud_type, **kwargs):
        self._dirty_mask = 0
        self.ep_cloud_type = ep_cloud_type
        self.end_point_dn = None
        self.child_action = None
        self.sacl = None
        self.status = None
        self.usr_lbl = None

        ManagedObject.__init__(self, "EtherPIoEndPoint", parent_mo_or_dn, **kwargs)



# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
This is an auto-generated module.
It contains supporting classes for Filter.

"""

from .ucscore import AbstractFilter


class AllbitsFilter(AbstractFilter):
    """This is AllbitsFilter class."""
    def __init__(self):
        AbstractFilter.__init__(self, "AllbitsFilter", "allbits")
        self.class_ = None
        self.property = None
        self.value = None

    def create(self, **kwargs):
        """This method populate the attribute of filter object."""
        self.class_ = kwargs['class_']
        self.property = kwargs['property']
        self.value = kwargs['value']


class AndFilter(AbstractFilter):
    """This is AndFilter class."""
    def __init__(self):
        AbstractFilter.__init__(self, "AndFilter", "and")

    def create(self, **kwargs):
        """This method populate the attribute of filter object."""
        pass


class AnybitFilter(AbstractFilter):
    """This is AnybitFilter class."""
    def __init__(self):
        AbstractFilter.__init__(self, "AnybitFilter", "anybit")
        self.class_ = None
        self.property = None
        self.value = None

    def create(self, **kwargs):
        """This method populate the attribute of filter object."""
        self.class_ = kwargs['class_']
        self.property = kwargs['property']
        self.value = kwargs['value']


class BwFilter(AbstractFilter):
    """This is BwFilter class."""
    def __init__(self):
        AbstractFilter.__init__(self, "BwFilter", "bw")
        self.class_ = None
        self.first_value = None
        self.property = None
        self.second_value = None

    def create(self, **kwargs):
        """This method populate the attribute of filter object."""
        self.class_ = kwargs['class_']
        self.first_value = kwargs['first_value']
        self.property = kwargs['property']
        self.second_value = kwargs['second_value']


class EqFilter(AbstractFilter):
    """This is EqFilter class."""
    def __init__(self):
        AbstractFilter.__init__(self, "EqFilter", "eq")
        self.class_ = None
        self.property = None
        self.value = None

    def create(self, **kwargs):
        """This method populate the attribute of filter object."""
        self.class_ = kwargs['class_']
        self.property = kwargs['property']
        self.value = kwargs['value']


class GeFilter(AbstractFilter):
    """This is GeFilter class."""
    def __init__(self):
        AbstractFilter.__init__(self, "GeFilter", "ge")
        self.class_ = None
        self.property = None
        self.value = None

    def create(self, **kwargs):
        """This method populate the attribute of filter object."""
        self.class_ = kwargs['class_']
        self.property = kwargs['property']
        self.value = kwargs['value']


class GtFilter(AbstractFilter):
    """This is GtFilter class."""
    def __init__(self):
        AbstractFilter.__init__(self, "GtFilter", "gt")
        self.class_ = None
        self.property = None
        self.value = None

    def create(self, **kwargs):
        """This method populate the attribute of filter object."""
        self.class_ = kwargs['class_']
        self.property = kwargs['property']
        self.value = kwargs['value']


class LeFilter(AbstractFilter):
    """This is LeFilter class."""
    def __init__(self):
        AbstractFilter.__init__(self, "LeFilter", "le")
        self.class_ = None
        self.property = None
        self.value = None

    def create(self, **kwargs):
        """This method populate the attribute of filter object."""
        self.class_ = kwargs['class_']
        self.property = kwargs['property']
        self.value = kwargs['value']


class LtFilter(AbstractFilter):
    """This is LtFilter class."""
    def __init__(self):
        AbstractFilter.__init__(self, "LtFilter", "lt")
        self.class_ = None
        self.property = None
        self.value = None

    def create(self, **kwargs):
        """This method populate the attribute of filter object."""
        self.class_ = kwargs['class_']
        self.property = kwargs['property']
        self.value = kwargs['value']


class NeFilter(AbstractFilter):
    """This is NeFilter class."""
    def __init__(self):
        AbstractFilter.__init__(self, "NeFilter", "ne")
        self.class_ = None
        self.property = None
        self.value = None

    def create(self, **kwargs):
        """This method populate the attribute of filter object."""
        self.class_ = kwargs['class_']
        self.property = kwargs['property']
        self.value = kwargs['value']


class NotFilter(AbstractFilter):
    """This is NotFilter class."""
    def __init__(self):
        AbstractFilter.__init__(self, "NotFilter", "not")

    def create(self, **kwargs):
        """This method populate the attribute of filter object."""
        pass


class OrFilter(AbstractFilter):
    """This is OrFilter class."""
    def __init__(self):
        AbstractFilter.__init__(self, "OrFilter", "or")

    def create(self, **kwargs):
        """This method populate the attribute of filter object."""
        pass


class WcardFilter(AbstractFilter):
    """This is WcardFilter class."""
    def __init__(self):
        AbstractFilter.__init__(self, "WcardFilter", "wcard")
        self.class_ = None
        self.property = None
        self.value = None

    def create(self, **kwargs):
        """This method populate the attribute of filter object."""
        self.class_ = kwargs['class_']
        self.property = kwargs['property']
        self.value = kwargs['value']



"""This module contains the general information for EtherServerIntFIoFsm ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class EtherServerIntFIoFsmConsts:
    COMPLETION_TIME_ = ""
    CURRENT_FSM_CONFIG = "Config"
    CURRENT_FSM_CONFIG_SPEED = "ConfigSpeed"
    CURRENT_FSM_NOP = "nop"
    FSM_STATUS_FAIL = "fail"
    FSM_STATUS_IN_PROGRESS = "inProgress"
    FSM_STATUS_NOP = "nop"
    FSM_STATUS_PENDING = "pending"
    FSM_STATUS_SKIP = "skip"
    FSM_STATUS_SUCCESS = "success"
    FSM_STATUS_THROTTLED = "throttled"
    RMT_ERR_CODE_ERR_2FA_AUTH_RETRY = "ERR-2fa-auth-retry"
    RMT_ERR_CODE_ERR_ACTIVATE_FAILED = "ERR-ACTIVATE-failed"
    RMT_ERR_CODE_ERR_ACTIVATE_IN_PROGRESS = "ERR-ACTIVATE-in-progress"
    RMT_ERR_CODE_ERR_ACTIVATE_RETRY = "ERR-ACTIVATE-retry"
    RMT_ERR_CODE_ERR_BIOS_TOKENS_OLD_BIOS = "ERR-BIOS-TOKENS-OLD-BIOS"
    RMT_ERR_CODE_ERR_BIOS_TOKENS_OLD_CIMC = "ERR-BIOS-TOKENS-OLD-CIMC"
    RMT_ERR_CODE_ERR_BIOS_NETWORK_BOOT_ORDER_NOT_FOUND = "ERR-BIOS-network-boot-order-not-found"
    RMT_ERR_CODE_ERR_BOARDCTRLUPDATE_IGNORE = "ERR-BOARDCTRLUPDATE-ignore"
    RMT_ERR_CODE_ERR_DIAG_CANCELLED = "ERR-DIAG-cancelled"
    RMT_ERR_CODE_ERR_DIAG_FSM_RESTARTED = "ERR-DIAG-fsm-restarted"
    RMT_ERR_CODE_ERR_DIAG_TEST_FAILED = "ERR-DIAG-test-failed"
    RMT_ERR_CODE_ERR_DNLD_AUTHENTICATION_FAILURE = "ERR-DNLD-authentication-failure"
    RMT_ERR_CODE_ERR_DNLD_HOSTKEY_MISMATCH = "ERR-DNLD-hostkey-mismatch"
    RMT_ERR_CODE_ERR_DNLD_INVALID_IMAGE = "ERR-DNLD-invalid-image"
    RMT_ERR_CODE_ERR_DNLD_NO_FILE = "ERR-DNLD-no-file"
    RMT_ERR_CODE_ERR_DNLD_NO_SPACE = "ERR-DNLD-no-space"
    RMT_ERR_CODE_ERR_DNLD_USB_UNMOUNTED = "ERR-DNLD-usb-unmounted"
    RMT_ERR_CODE_ERR_DNS_DELETE_ERROR = "ERR-DNS-delete-error"
    RMT_ERR_CODE_ERR_DNS_GET_ERROR = "ERR-DNS-get-error"
    RMT_ERR_CODE_ERR_DNS_SET_ERROR = "ERR-DNS-set-error"
    RMT_ERR_CODE_ERR_DIAGNOSTICS_IN_PROGRESS = "ERR-Diagnostics-in-progress"
    RMT_ERR_CODE_ERR_DIAGNOSTICS_MEMTEST_IN_PROGRESS = "ERR-Diagnostics-memtest-in-progress"
    RMT_ERR_CODE_ERR_DIAGNOSTICS_NETWORK_IN_PROGRESS = "ERR-Diagnostics-network-in-progress"
    RMT_ERR_CODE_ERR_FILTER_ILLEGAL_FORMAT = "ERR-FILTER-illegal-format"
    RMT_ERR_CODE_ERR_FSM_NO_SUCH_STATE = "ERR-FSM-no-such-state"
    RMT_ERR_CODE_ERR_HOST_FRU_IDENTITY_MISMATCH = "ERR-HOST-fru-identity-mismatch"
    RMT_ERR_CODE_ERR_HTTP_SET_ERROR = "ERR-HTTP-set-error"
    RMT_ERR_CODE_ERR_HTTPS_SET_ERROR = "ERR-HTTPS-set-error"
    RMT_ERR_CODE_ERR_IBMC_ANALYZE_RESULTS = "ERR-IBMC-analyze-results"
    RMT_ERR_CODE_ERR_IBMC_CONNECT_ERROR = "ERR-IBMC-connect-error"
    RMT_ERR_CODE_ERR_IBMC_CONNECTOR_INFO_RETRIEVAL_ERROR = "ERR-IBMC-connector-info-retrieval-error"
    RMT_ERR_CODE_ERR_IBMC_FRU_RETRIEVAL_ERROR = "ERR-IBMC-fru-retrieval-error"
    RMT_ERR_CODE_ERR_IBMC_INVALID_END_POINT_CONFIG = "ERR-IBMC-invalid-end-point-config"
    RMT_ERR_CODE_ERR_IBMC_RESULTS_NOT_READY = "ERR-IBMC-results-not-ready"
    RMT_ERR_CODE_ERR_MAX_SUBSCRIPTIONS_ALLOWED_ERROR = "ERR-MAX-subscriptions-allowed-error"
    RMT_ERR_CODE_ERR_MO_CONFIG_CHILD_OBJECT_CANT_BE_CONFIGURED = "ERR-MO-CONFIG-child-object-cant-be-configured"
    RMT_ERR_CODE_ERR_MO_META_NO_SUCH_OBJECT_CLASS = "ERR-MO-META-no-such-object-class"
    RMT_ERR_CODE_ERR_MO_PROPERTY_NO_SUCH_PROPERTY = "ERR-MO-PROPERTY-no-such-property"
    RMT_ERR_CODE_ERR_MO_PROPERTY_VALUE_OUT_OF_RANGE = "ERR-MO-PROPERTY-value-out-of-range"
    RMT_ERR_CODE_ERR_MO_ACCESS_DENIED = "ERR-MO-access-denied"
    RMT_ERR_CODE_ERR_MO_DELETION_RULE_VIOLATION = "ERR-MO-deletion-rule-violation"
    RMT_ERR_CODE_ERR_MO_DUPLICATE_OBJECT = "ERR-MO-duplicate-object"
    RMT_ERR_CODE_ERR_MO_ILLEGAL_CONTAINMENT = "ERR-MO-illegal-containment"
    RMT_ERR_CODE_ERR_MO_ILLEGAL_CREATION = "ERR-MO-illegal-creation"
    RMT_ERR_CODE_ERR_MO_ILLEGAL_ITERATOR_STATE = "ERR-MO-illegal-iterator-state"
    RMT_ERR_CODE_ERR_MO_ILLEGAL_OBJECT_LIFECYCLE_TRANSITION = "ERR-MO-illegal-object-lifecycle-transition"
    RMT_ERR_CODE_ERR_MO_NAMING_RULE_VIOLATION = "ERR-MO-naming-rule-violation"
    RMT_ERR_CODE_ERR_MO_OBJECT_NOT_FOUND = "ERR-MO-object-not-found"
    RMT_ERR_CODE_ERR_MO_RESOURCE_ALLOCATION = "ERR-MO-resource-allocation"
    RMT_ERR_CODE_ERR_NTP_DELETE_ERROR = "ERR-NTP-delete-error"
    RMT_ERR_CODE_ERR_NTP_GET_ERROR = "ERR-NTP-get-error"
    RMT_ERR_CODE_ERR_NTP_SET_ERROR = "ERR-NTP-set-error"
    RMT_ERR_CODE_ERR_POWER_CAP_UNSUPPORTED = "ERR-POWER-CAP-UNSUPPORTED"
    RMT_ERR_CODE_ERR_POWER_PROFILE_IN_PROGRESS = "ERR-POWER-PROFILE-IN-PROGRESS"
    RMT_ERR_CODE_ERR_SERVER_MIS_CONNECT = "ERR-SERVER-mis-connect"
    RMT_ERR_CODE_ERR_SWITCH_INVALID_IF_CONFIG = "ERR-SWITCH-invalid-if-config"
    RMT_ERR_CODE_ERR_TOKEN_REQUEST_DENIED = "ERR-TOKEN-request-denied"
    RMT_ERR_CODE_ERR_UNABLE_TO_FETCH_BIOS_SETTINGS = "ERR-UNABLE-TO-FETCH-BIOS-SETTINGS"
    RMT_ERR_CODE_ERR_UPDATE_FAILED = "ERR-UPDATE-failed"
    RMT_ERR_CODE_ERR_UPDATE_IN_PROGRESS = "ERR-UPDATE-in-progress"
    RMT_ERR_CODE_ERR_UPDATE_RETRY = "ERR-UPDATE-retry"
    RMT_ERR_CODE_ERR_AAA_CONFIG_MODIFY_ERROR = "ERR-aaa-config-modify-error"
    RMT_ERR_CODE_ERR_ACCT_REALM_SET_ERROR = "ERR-acct-realm-set-error"
    RMT_ERR_CODE_ERR_ADMIN_PASSWD_SET = "ERR-admin-passwd-set"
    RMT_ERR_CODE_ERR_AUTH_ISSUE = "ERR-auth-issue"
    RMT_ERR_CODE_ERR_AUTH_REALM_GET_ERROR = "ERR-auth-realm-get-error"
    RMT_ERR_CODE_ERR_AUTH_REALM_SET_ERROR = "ERR-auth-realm-set-error"
    RMT_ERR_CODE_ERR_AUTHENTICATION = "ERR-authentication"
    RMT_ERR_CODE_ERR_AUTHORIZATION_REQUIRED = "ERR-authorization-required"
    RMT_ERR_CODE_ERR_CLI_SESSION_LIMIT_REACHED = "ERR-cli-session-limit-reached"
    RMT_ERR_CODE_ERR_CREATE_KEYRING = "ERR-create-keyring"
    RMT_ERR_CODE_ERR_CREATE_LOCALE = "ERR-create-locale"
    RMT_ERR_CODE_ERR_CREATE_ROLE = "ERR-create-role"
    RMT_ERR_CODE_ERR_CREATE_TP = "ERR-create-tp"
    RMT_ERR_CODE_ERR_CREATE_USER = "ERR-create-user"
    RMT_ERR_CODE_ERR_DELETE_LOCALE = "ERR-delete-locale"
    RMT_ERR_CODE_ERR_DELETE_ROLE = "ERR-delete-role"
    RMT_ERR_CODE_ERR_DELETE_SESSION = "ERR-delete-session"
    RMT_ERR_CODE_ERR_DELETE_USER = "ERR-delete-user"
    RMT_ERR_CODE_ERR_DOWNGRADE_FAIL = "ERR-downgrade-fail"
    RMT_ERR_CODE_ERR_EFI_DIAGNOSTICS_IN_PROGRESS = "ERR-efi-Diagnostics--in-progress"
    RMT_ERR_CODE_ERR_ENABLE_MGMT_CONN = "ERR-enable-mgmt-conn"
    RMT_ERR_CODE_ERR_EP_SET_ERROR = "ERR-ep-set-error"
    RMT_ERR_CODE_ERR_GET_MAX_HTTP_USER_SESSIONS = "ERR-get-max-http-user-sessions"
    RMT_ERR_CODE_ERR_HTTP_INITIALIZING = "ERR-http-initializing"
    RMT_ERR_CODE_ERR_INSUFFICIENTLY_EQUIPPED = "ERR-insufficiently-equipped"
    RMT_ERR_CODE_ERR_INTERNAL_ERROR = "ERR-internal-error"
    RMT_ERR_CODE_ERR_LDAP_DELETE_ERROR = "ERR-ldap-delete-error"
    RMT_ERR_CODE_ERR_LDAP_GET_ERROR = "ERR-ldap-get-error"
    RMT_ERR_CODE_ERR_LDAP_GROUP_MODIFY_ERROR = "ERR-ldap-group-modify-error"
    RMT_ERR_CODE_ERR_LDAP_GROUP_SET_ERROR = "ERR-ldap-group-set-error"
    RMT_ERR_CODE_ERR_LDAP_SET_ERROR = "ERR-ldap-set-error"
    RMT_ERR_CODE_ERR_LOCALE_SET_ERROR = "ERR-locale-set-error"
    RMT_ERR_CODE_ERR_MAX_USERID_SESSIONS_REACHED = "ERR-max-userid-sessions-reached"
    RMT_ERR_CODE_ERR_MISSING_METHOD = "ERR-missing-method"
    RMT_ERR_CODE_ERR_MODIFY_LOCALE = "ERR-modify-locale"
    RMT_ERR_CODE_ERR_MODIFY_ROLE = "ERR-modify-role"
    RMT_ERR_CODE_ERR_MODIFY_USER = "ERR-modify-user"
    RMT_ERR_CODE_ERR_MODIFY_USER_LOCALE = "ERR-modify-user-locale"
    RMT_ERR_CODE_ERR_MODIFY_USER_ROLE = "ERR-modify-user-role"
    RMT_ERR_CODE_ERR_PROVIDER_GROUP_MODIFY_ERROR = "ERR-provider-group-modify-error"
    RMT_ERR_CODE_ERR_PROVIDER_GROUP_SET_ERROR = "ERR-provider-group-set-error"
    RMT_ERR_CODE_ERR_RADIUS_GET_ERROR = "ERR-radius-get-error"
    RMT_ERR_CODE_ERR_RADIUS_GLOBAL_SET_ERROR = "ERR-radius-global-set-error"
    RMT_ERR_CODE_ERR_RADIUS_GROUP_SET_ERROR = "ERR-radius-group-set-error"
    RMT_ERR_CODE_ERR_RADIUS_SET_ERROR = "ERR-radius-set-error"
    RMT_ERR_CODE_ERR_REQUEST_TIMEOUT = "ERR-request-timeout"
    RMT_ERR_CODE_ERR_RESET_ADAPTER = "ERR-reset-adapter"
    RMT_ERR_CODE_ERR_ROLE_SET_ERROR = "ERR-role-set-error"
    RMT_ERR_CODE_ERR_SECONDARY_NODE = "ERR-secondary-node"
    RMT_ERR_CODE_ERR_SERVICE_NOT_READY = "ERR-service-not-ready"
    RMT_ERR_CODE_ERR_SESSION_CACHE_FULL = "ERR-session-cache-full"
    RMT_ERR_CODE_ERR_SESSION_NOT_FOUND = "ERR-session-not-found"
    RMT_ERR_CODE_ERR_SET_KEY_CERT = "ERR-set-key-cert"
    RMT_ERR_CODE_ERR_SET_LOGIN_PROFILE = "ERR-set-login-profile"
    RMT_ERR_CODE_ERR_SET_MIN_PASSPHRASE_LENGTH = "ERR-set-min-passphrase-length"
    RMT_ERR_CODE_ERR_SET_NETWORK = "ERR-set-network"
    RMT_ERR_CODE_ERR_SET_PASSWORD_STRENGTH_CHECK = "ERR-set-password-strength-check"
    RMT_ERR_CODE_ERR_SET_PORT_CHANNEL = "ERR-set-port-channel"
    RMT_ERR_CODE_ERR_STORE_PRE_LOGIN_BANNER_MSG = "ERR-store-pre-login-banner-msg"
    RMT_ERR_CODE_ERR_TACACS_ENABLE_ERROR = "ERR-tacacs-enable-error"
    RMT_ERR_CODE_ERR_TACACS_GLOBAL_SET_ERROR = "ERR-tacacs-global-set-error"
    RMT_ERR_CODE_ERR_TACACS_GROUP_SET_ERROR = "ERR-tacacs-group-set-error"
    RMT_ERR_CODE_ERR_TACACS_PLUS_GET_ERROR = "ERR-tacacs-plus-get-error"
    RMT_ERR_CODE_ERR_TACACS_SET_ERROR = "ERR-tacacs-set-error"
    RMT_ERR_CODE_ERR_TEST_ERROR_1 = "ERR-test-error-1"
    RMT_ERR_CODE_ERR_TEST_ERROR_2 = "ERR-test-error-2"
    RMT_ERR_CODE_ERR_TIMEZONE_SET_ERROR = "ERR-timezone-set-error"
    RMT_ERR_CODE_ERR_USER_ACCOUNT_EXPIRED = "ERR-user-account-expired"
    RMT_ERR_CODE_ERR_USER_PASSWD_EXPIRED = "ERR-user-passwd-expired"
    RMT_ERR_CODE_ERR_USER_SET_ERROR = "ERR-user-set-error"
    RMT_ERR_CODE_ERR_XML_PARSE_ERROR = "ERR-xml-parse-error"
    RMT_ERR_CODE_NONE = "none"


class EtherServerIntFIoFsm(ManagedObject):
    """This is EtherServerIntFIoFsm class."""

    consts = EtherServerIntFIoFsmConsts()
    naming_props = set([])

    mo_meta = MoMeta("EtherServerIntFIoFsm", "etherServerIntFIoFsm", "fsm", VersionMeta.Version211a, "OutputOnly", 0xf, [], [""], ['etherServerIntFIo'], ['etherServerIntFIoFsmStage'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version211a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "completion_time": MoPropertyMeta("completion_time", "completionTime", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [""], []),
        "current_fsm": MoPropertyMeta("current_fsm", "currentFsm", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["Config", "ConfigSpeed", "nop"], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "fsm_status": MoPropertyMeta("fsm_status", "fsmStatus", "string", VersionMeta.Version211a, MoPropertyMeta.INTERNAL, None, None, None, None, ["fail", "inProgress", "nop", "pending", "skip", "success", "throttled"], []),
        "instance_id": MoPropertyMeta("instance_id", "instanceId", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "progress": MoPropertyMeta("progress", "progress", "byte", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-100"]),
        "rmt_err_code": MoPropertyMeta("rmt_err_code", "rmtErrCode", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["ERR-2fa-auth-retry", "ERR-ACTIVATE-failed", "ERR-ACTIVATE-in-progress", "ERR-ACTIVATE-retry", "ERR-BIOS-TOKENS-OLD-BIOS", "ERR-BIOS-TOKENS-OLD-CIMC", "ERR-BIOS-network-boot-order-not-found", "ERR-BOARDCTRLUPDATE-ignore", "ERR-DIAG-cancelled", "ERR-DIAG-fsm-restarted", "ERR-DIAG-test-failed", "ERR-DNLD-authentication-failure", "ERR-DNLD-hostkey-mismatch", "ERR-DNLD-invalid-image", "ERR-DNLD-no-file", "ERR-DNLD-no-space", "ERR-DNLD-usb-unmounted", "ERR-DNS-delete-error", "ERR-DNS-get-error", "ERR-DNS-set-error", "ERR-Diagnostics-in-progress", "ERR-Diagnostics-memtest-in-progress", "ERR-Diagnostics-network-in-progress", "ERR-FILTER-illegal-format", "ERR-FSM-no-such-state", "ERR-HOST-fru-identity-mismatch", "ERR-HTTP-set-error", "ERR-HTTPS-set-error", "ERR-IBMC-analyze-results", "ERR-IBMC-connect-error", "ERR-IBMC-connector-info-retrieval-error", "ERR-IBMC-fru-retrieval-error", "ERR-IBMC-invalid-end-point-config", "ERR-IBMC-results-not-ready", "ERR-MAX-subscriptions-allowed-error", "ERR-MO-CONFIG-child-object-cant-be-configured", "ERR-MO-META-no-such-object-class", "ERR-MO-PROPERTY-no-such-property", "ERR-MO-PROPERTY-value-out-of-range", "ERR-MO-access-denied", "ERR-MO-deletion-rule-violation", "ERR-MO-duplicate-object", "ERR-MO-illegal-containment", "ERR-MO-illegal-creation", "ERR-MO-illegal-iterator-state", "ERR-MO-illegal-object-lifecycle-transition", "ERR-MO-naming-rule-violation", "ERR-MO-object-not-found", "ERR-MO-resource-allocation", "ERR-NTP-delete-error", "ERR-NTP-get-error", "ERR-NTP-set-error", "ERR-POWER-CAP-UNSUPPORTED", "ERR-POWER-PROFILE-IN-PROGRESS", "ERR-SERVER-mis-connect", "ERR-SWITCH-invalid-if-config", "ERR-TOKEN-request-denied", "ERR-UNABLE-TO-FETCH-BIOS-SETTINGS", "ERR-UPDATE-failed", "ERR-UPDATE-in-progress", "ERR-UPDATE-retry", "ERR-aaa-config-modify-error", "ERR-acct-realm-set-error", "ERR-admin-passwd-set", "ERR-auth-issue", "ERR-auth-realm-get-error", "ERR-auth-realm-set-error", "ERR-authentication", "ERR-authorization-required", "ERR-cli-session-limit-reached", "ERR-create-keyring", "ERR-create-locale", "ERR-create-role", "ERR-create-tp", "ERR-create-user", "ERR-delete-locale", "ERR-delete-role", "ERR-delete-session", "ERR-delete-user", "ERR-downgrade-fail", "ERR-efi-Diagnostics--in-progress", "ERR-enable-mgmt-conn", "ERR-ep-set-error", "ERR-get-max-http-user-sessions", "ERR-http-initializing", "ERR-insufficiently-equipped", "ERR-internal-error", "ERR-ldap-delete-error", "ERR-ldap-get-error", "ERR-ldap-group-modify-error", "ERR-ldap-group-set-error", "ERR-ldap-set-error", "ERR-locale-set-error", "ERR-max-userid-sessions-reached", "ERR-missing-method", "ERR-modify-locale", "ERR-modify-role", "ERR-modify-user", "ERR-modify-user-locale", "ERR-modify-user-role", "ERR-provider-group-modify-error", "ERR-provider-group-set-error", "ERR-radius-get-error", "ERR-radius-global-set-error", "ERR-radius-group-set-error", "ERR-radius-set-error", "ERR-request-timeout", "ERR-reset-adapter", "ERR-role-set-error", "ERR-secondary-node", "ERR-service-not-ready", "ERR-session-cache-full", "ERR-session-not-found", "ERR-set-key-cert", "ERR-set-login-profile", "ERR-set-min-passphrase-length", "ERR-set-network", "ERR-set-password-strength-check", "ERR-set-port-channel", "ERR-store-pre-login-banner-msg", "ERR-tacacs-enable-error", "ERR-tacacs-global-set-error", "ERR-tacacs-group-set-error", "ERR-tacacs-plus-get-error", "ERR-tacacs-set-error", "ERR-test-error-1", "ERR-test-error-2", "ERR-timezone-set-error", "ERR-user-account-expired", "ERR-user-passwd-expired", "ERR-user-set-error", "ERR-xml-parse-error", "none"], ["0-4294967295"]),
        "rmt_err_descr": MoPropertyMeta("rmt_err_descr", "rmtErrDescr", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "rmt_rslt": MoPropertyMeta("rmt_rslt", "rmtRslt", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|not-applicable|resource-unavailable|service-unavailable|intermittent-error|sw-defect|service-not-implemented-ignore|extend-timeout|capability-not-implemented-failure|illegal-fru|end-point-unavailable|failure|resource-capacity-exceeded|service-protocol-error|fw-defect|service-not-implemented-fail|task-reset|unidentified-fail|capability-not-supported|end-point-failed|fru-state-indeterminate|resource-dependency|fru-identity-indeterminate|internal-error|hw-defect|service-not-supported|fru-not-supported|end-point-protocol-error|capability-unavailable|fru-not-ready|capability-not-implemented-ignore|fru-info-malformed|timeout),){0,32}(defaultValue|not-applicable|resource-unavailable|service-unavailable|intermittent-error|sw-defect|service-not-implemented-ignore|extend-timeout|capability-not-implemented-failure|illegal-fru|end-point-unavailable|failure|resource-capacity-exceeded|service-protocol-error|fw-defect|service-not-implemented-fail|task-reset|unidentified-fail|capability-not-supported|end-point-failed|fru-state-indeterminate|resource-dependency|fru-identity-indeterminate|internal-error|hw-defect|service-not-supported|fru-not-supported|end-point-protocol-error|capability-unavailable|fru-not-ready|capability-not-implemented-ignore|fru-info-malformed|timeout){0,1}""", [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "completionTime": "completion_time", 
        "currentFsm": "current_fsm", 
        "descr": "descr", 
        "dn": "dn", 
        "fsmStatus": "fsm_status", 
        "instanceId": "instance_id", 
        "progress": "progress", 
        "rmtErrCode": "rmt_err_code", 
        "rmtErrDescr": "rmt_err_descr", 
        "rmtRslt": "rmt_rslt", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.completion_time = None
        self.current_fsm = None
        self.descr = None
        self.fsm_status = None
        self.instance_id = None
        self.progress = None
        self.rmt_err_code = None
        self.rmt_err_descr = None
        self.rmt_rslt = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "EtherServerIntFIoFsm", parent_mo_or_dn, **kwargs)



"""This module contains the general information for FirmwareSpec ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class FirmwareSpecConsts:
    pass


class FirmwareSpec(ManagedObject):
    """This is FirmwareSpec class."""

    consts = FirmwareSpecConsts()
    naming_props = set(['bundleVersion'])

    mo_meta = MoMeta("FirmwareSpec", "firmwareSpec", "fw-spec-bundle-version-[bundle_version]", VersionMeta.Version141i, "InputOutput", 0x3f, [], [""], ['adaptorFruCapProvider'], [], ["Get"])

    prop_meta = {
        "bundle_version": MoPropertyMeta("bundle_version", "bundleVersion", "string", VersionMeta.Version141i, MoPropertyMeta.NAMING, 0x2, 1, 510, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version141i, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "eth_efi_version": MoPropertyMeta("eth_efi_version", "ethEFIVersion", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "eth_option_rom_version": MoPropertyMeta("eth_option_rom_version", "ethOptionRomVersion", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "fc_fw_version": MoPropertyMeta("fc_fw_version", "fcFWVersion", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "fc_option_rom_version": MoPropertyMeta("fc_option_rom_version", "fcOptionRomVersion", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "bundleVersion": "bundle_version", 
        "childAction": "child_action", 
        "dn": "dn", 
        "ethEFIVersion": "eth_efi_version", 
        "ethOptionRomVersion": "eth_option_rom_version", 
        "fcFWVersion": "fc_fw_version", 
        "fcOptionRomVersion": "fc_option_rom_version", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, bundle_version, **kwargs):
        self._dirty_mask = 0
        self.bundle_version = bundle_version
        self.child_action = None
        self.eth_efi_version = None
        self.eth_option_rom_version = None
        self.fc_fw_version = None
        self.fc_option_rom_version = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "FirmwareSpec", parent_mo_or_dn, **kwargs)



"""This module contains the general information for VmVif ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class VmVifConsts:
    LINK_STATE_ADMIN_DOWN = "admin-down"
    LINK_STATE_DOWN = "down"
    LINK_STATE_ERROR = "error"
    LINK_STATE_OFFLINE = "offline"
    LINK_STATE_UNALLOCATED = "unallocated"
    LINK_STATE_UNAVAILABLE = "unavailable"
    LINK_STATE_UNKNOWN = "unknown"
    LINK_STATE_UP = "up"
    OPER_STATE_ACTIVE = "active"
    OPER_STATE_ADMIN_DOWN = "admin-down"
    OPER_STATE_ERROR = "error"
    OPER_STATE_LINK_DOWN = "link-down"
    OPER_STATE_PASSIVE = "passive"
    OPER_STATE_UNKNOWN = "unknown"
    PH_SWITCH_ID_A = "A"
    PH_SWITCH_ID_B = "B"
    PH_SWITCH_ID_NONE = "NONE"
    V_STATUS_OFFLINE = "offline"
    V_STATUS_ONLINE = "online"
    V_STATUS_UNKNOWN = "unknown"


class VmVif(ManagedObject):
    """This is VmVif class."""

    consts = VmVifConsts()
    naming_props = set(['phSwitchId', 'vifId'])

    mo_meta = MoMeta("VmVif", "vmVif", "sw-[ph_switch_id]vif-[vif_id]", VersionMeta.Version111j, "InputOutput", 0x7f, [], ["admin"], ['vmNic'], ['faultInst'], ["Get"])

    prop_meta = {
        "adp_vif_id": MoPropertyMeta("adp_vif_id", "adpVifId", "uint", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111j, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "cookie": MoPropertyMeta("cookie", "cookie", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "link_state": MoPropertyMeta("link_state", "linkState", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["admin-down", "down", "error", "offline", "unallocated", "unavailable", "unknown", "up"], []),
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["active", "admin-down", "error", "link-down", "passive", "unknown"], []),
        "ph_switch_id": MoPropertyMeta("ph_switch_id", "phSwitchId", "string", VersionMeta.Version111j, MoPropertyMeta.NAMING, 0x8, None, None, None, ["A", "B", "NONE"], []),
        "phs_access_aggr_port_id": MoPropertyMeta("phs_access_aggr_port_id", "phsAccessAggrPortId", "uint", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "phs_access_card_id": MoPropertyMeta("phs_access_card_id", "phsAccessCardId", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "phs_access_port_id": MoPropertyMeta("phs_access_port_id", "phsAccessPortId", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "phs_border_aggr_port_id": MoPropertyMeta("phs_border_aggr_port_id", "phsBorderAggrPortId", "uint", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "phs_border_card_id": MoPropertyMeta("phs_border_card_id", "phsBorderCardId", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "phs_border_port_id": MoPropertyMeta("phs_border_port_id", "phsBorderPortId", "uint", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "state_qual": MoPropertyMeta("state_qual", "stateQual", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111j, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "status_change_ts": MoPropertyMeta("status_change_ts", "statusChangeTs", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []),
        "v_status": MoPropertyMeta("v_status", "vStatus", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, None, None, None, ["offline", "online", "unknown"], []),
        "vc_dn": MoPropertyMeta("vc_dn", "vcDn", "string", VersionMeta.Version111j, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "vif_id": MoPropertyMeta("vif_id", "vifId", "uint", VersionMeta.Version111j, MoPropertyMeta.NAMING, 0x40, None, None, None, [], []),
    }

    prop_map = {
        "adpVifId": "adp_vif_id", 
        "childAction": "child_action", 
        "cookie": "cookie", 
        "dn": "dn", 
        "linkState": "link_state", 
        "operState": "oper_state", 
        "phSwitchId": "ph_switch_id", 
        "phsAccessAggrPortId": "phs_access_aggr_port_id", 
        "phsAccessCardId": "phs_access_card_id", 
        "phsAccessPortId": "phs_access_port_id", 
        "phsBorderAggrPortId": "phs_border_aggr_port_id", 
        "phsBorderCardId": "phs_border_card_id", 
        "phsBorderPortId": "phs_border_port_id", 
        "rn": "rn", 
        "sacl": "sacl", 
        "stateQual": "state_qual", 
        "status": "status", 
        "statusChangeTs": "status_change_ts", 
        "vStatus": "v_status", 
        "vcDn": "vc_dn", 
        "vifId": "vif_id", 
    }

    def __init__(self, parent_mo_or_dn, ph_switch_id, vif_id, **kwargs):
        self._dirty_mask = 0
        self.ph_switch_id = ph_switch_id
        self.vif_id = vif_id
        self.adp_vif_id = None
        self.child_action = None
        self.cookie = None
        self.link_state = None
        self.oper_state = None
        self.phs_access_aggr_port_id = None
        self.phs_access_card_id = None
        self.phs_access_port_id = None
        self.phs_border_aggr_port_id = None
        self.phs_border_card_id = None
        self.phs_border_port_id = None
        self.sacl = None
        self.state_qual = None
        self.status = None
        self.status_change_ts = None
        self.v_status = None
        self.vc_dn = None

        ManagedObject.__init__(self, "VmVif", parent_mo_or_dn, **kwargs)



"""This module contains the general information for AdaptorHostIscsiIf ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class AdaptorHostIscsiIfConsts:
    ADMIN_STATE_DISABLED = "disabled"
    ADMIN_STATE_DISABLED_ACTIVE = "disabled-active"
    ADMIN_STATE_DISABLED_PASSIVE = "disabled-passive"
    ADMIN_STATE_ENABLED = "enabled"
    ADMIN_STATE_ENABLED_ACTIVE = "enabled-active"
    ADMIN_STATE_ENABLED_PASSIVE = "enabled-passive"
    ADMIN_STATE_RESET_CONNECTIVITY = "reset-connectivity"
    ADMIN_STATE_RESET_CONNECTIVITY_ACTIVE = "reset-connectivity-active"
    ADMIN_STATE_RESET_CONNECTIVITY_PASSIVE = "reset-connectivity-passive"
    BOOT_DEV_DISABLED = "disabled"
    BOOT_DEV_ENABLED = "enabled"
    CHASSIS_ID_N_A = "N/A"
    DISCOVERY_ABSENT = "absent"
    DISCOVERY_MIS_CONNECT = "mis-connect"
    DISCOVERY_MISSING = "missing"
    DISCOVERY_NEW = "new"
    DISCOVERY_PRESENT = "present"
    DISCOVERY_UN_INITIALIZED = "un-initialized"
    DISCOVERY_UN_SUPPORTED = "un-supported"
    HOST_VISIBLE_NO = "no"
    HOST_VISIBLE_OS_DEPENDENT = "os-dependent"
    HOST_VISIBLE_YES = "yes"
    IF_ROLE_DIAG = "diag"
    IF_ROLE_FCOE_NAS_STORAGE = "fcoe-nas-storage"
    IF_ROLE_FCOE_STORAGE = "fcoe-storage"
    IF_ROLE_FCOE_UPLINK = "fcoe-uplink"
    IF_ROLE_MGMT = "mgmt"
    IF_ROLE_MONITOR = "monitor"
    IF_ROLE_NAS_STORAGE = "nas-storage"
    IF_ROLE_NETWORK = "network"
    IF_ROLE_NETWORK_FCOE_UPLINK = "network-fcoe-uplink"
    IF_ROLE_SERVER = "server"
    IF_ROLE_SERVICE = "service"
    IF_ROLE_STORAGE = "storage"
    IF_ROLE_UNKNOWN = "unknown"
    IF_TYPE_AGGREGATION = "aggregation"
    IF_TYPE_PHYSICAL = "physical"
    IF_TYPE_UNKNOWN = "unknown"
    IF_TYPE_VIRTUAL = "virtual"
    LC_ALLOCATED = "allocated"
    LC_AVAILABLE = "available"
    LC_DEALLOCATED = "deallocated"
    LC_REPURPOSED = "repurposed"
    LINK_STATE_ADMIN_DOWN = "admin-down"
    LINK_STATE_DOWN = "down"
    LINK_STATE_ERROR = "error"
    LINK_STATE_OFFLINE = "offline"
    LINK_STATE_UNALLOCATED = "unallocated"
    LINK_STATE_UNAVAILABLE = "unavailable"
    LINK_STATE_UNKNOWN = "unknown"
    LINK_STATE_UP = "up"
    OPER_STATE_ACCESSIBILITY_PROBLEM = "accessibility-problem"
    OPER_STATE_AUTO_UPGRADE = "auto-upgrade"
    OPER_STATE_BACKPLANE_PORT_PROBLEM = "backplane-port-problem"
    OPER_STATE_BIOS_POST_TIMEOUT = "bios-post-timeout"
    OPER_STATE_CHASSIS_INTRUSION = "chassis-intrusion"
    OPER_STATE_CHASSIS_LIMIT_EXCEEDED = "chassis-limit-exceeded"
    OPER_STATE_CONFIG = "config"
    OPER_STATE_DECOMISSIONING = "decomissioning"
    OPER_STATE_DEGRADED = "degraded"
    OPER_STATE_DISABLED = "disabled"
    OPER_STATE_DISCOVERY = "discovery"
    OPER_STATE_DISCOVERY_FAILED = "discovery-failed"
    OPER_STATE_EQUIPMENT_PROBLEM = "equipment-problem"
    OPER_STATE_FABRIC_CONN_PROBLEM = "fabric-conn-problem"
    OPER_STATE_FABRIC_UNSUPPORTED_CONN = "fabric-unsupported-conn"
    OPER_STATE_IDENTIFY = "identify"
    OPER_STATE_IDENTITY_UNESTABLISHABLE = "identity-unestablishable"
    OPER_STATE_INOPERABLE = "inoperable"
    OPER_STATE_LINK_ACTIVATE_BLOCKED = "link-activate-blocked"
    OPER_STATE_MALFORMED_FRU = "malformed-fru"
    OPER_STATE_NON_OPTIMAL = "non-optimal"
    OPER_STATE_NON_OPTIMAL_SEVERE = "non-optimal-severe"
    OPER_STATE_NOT_SUPPORTED = "not-supported"
    OPER_STATE_OPERABLE = "operable"
    OPER_STATE_PEER_COMM_PROBLEM = "peer-comm-problem"
    OPER_STATE_PERFORMANCE_PROBLEM = "performance-problem"
    OPER_STATE_POST_FAILURE = "post-failure"
    OPER_STATE_POWER_PROBLEM = "power-problem"
    OPER_STATE_POWERED_OFF = "powered-off"
    OPER_STATE_REMOVED = "removed"
    OPER_STATE_THERMAL_PROBLEM = "thermal-problem"
    OPER_STATE_UNKNOWN = "unknown"
    OPER_STATE_UNSUPPORTED_CONFIG = "unsupported-config"
    OPER_STATE_UPGRADE_PROBLEM = "upgrade-problem"
    OPER_STATE_VOLTAGE_PROBLEM = "voltage-problem"
    OPERABILITY_ACCESSIBILITY_PROBLEM = "accessibility-problem"
    OPERABILITY_AUTO_UPGRADE = "auto-upgrade"
    OPERABILITY_BACKPLANE_PORT_PROBLEM = "backplane-port-problem"
    OPERABILITY_BIOS_POST_TIMEOUT = "bios-post-timeout"
    OPERABILITY_CHASSIS_INTRUSION = "chassis-intrusion"
    OPERABILITY_CHASSIS_LIMIT_EXCEEDED = "chassis-limit-exceeded"
    OPERABILITY_CONFIG = "config"
    OPERABILITY_DECOMISSIONING = "decomissioning"
    OPERABILITY_DEGRADED = "degraded"
    OPERABILITY_DISABLED = "disabled"
    OPERABILITY_DISCOVERY = "discovery"
    OPERABILITY_DISCOVERY_FAILED = "discovery-failed"
    OPERABILITY_EQUIPMENT_PROBLEM = "equipment-problem"
    OPERABILITY_FABRIC_CONN_PROBLEM = "fabric-conn-problem"
    OPERABILITY_FABRIC_UNSUPPORTED_CONN = "fabric-unsupported-conn"
    OPERABILITY_IDENTIFY = "identify"
    OPERABILITY_IDENTITY_UNESTABLISHABLE = "identity-unestablishable"
    OPERABILITY_INOPERABLE = "inoperable"
    OPERABILITY_LINK_ACTIVATE_BLOCKED = "link-activate-blocked"
    OPERABILITY_MALFORMED_FRU = "malformed-fru"
    OPERABILITY_NON_OPTIMAL = "non-optimal"
    OPERABILITY_NON_OPTIMAL_SEVERE = "non-optimal-severe"
    OPERABILITY_NOT_SUPPORTED = "not-supported"
    OPERABILITY_OPERABLE = "operable"
    OPERABILITY_PEER_COMM_PROBLEM = "peer-comm-problem"
    OPERABILITY_PERFORMANCE_PROBLEM = "performance-problem"
    OPERABILITY_POST_FAILURE = "post-failure"
    OPERABILITY_POWER_PROBLEM = "power-problem"
    OPERABILITY_POWERED_OFF = "powered-off"
    OPERABILITY_REMOVED = "removed"
    OPERABILITY_THERMAL_PROBLEM = "thermal-problem"
    OPERABILITY_UNKNOWN = "unknown"
    OPERABILITY_UNSUPPORTED_CONFIG = "unsupported-config"
    OPERABILITY_UPGRADE_PROBLEM = "upgrade-problem"
    OPERABILITY_VOLTAGE_PROBLEM = "voltage-problem"
    ORDER_UNSPECIFIED = "unspecified"
    PEER_CHASSIS_ID_N_A = "N/A"
    PERF_LOWER_CRITICAL = "lower-critical"
    PERF_LOWER_NON_CRITICAL = "lower-non-critical"
    PERF_LOWER_NON_RECOVERABLE = "lower-non-recoverable"
    PERF_NOT_SUPPORTED = "not-supported"
    PERF_OK = "ok"
    PERF_UNKNOWN = "unknown"
    PERF_UPPER_CRITICAL = "upper-critical"
    PERF_UPPER_NON_CRITICAL = "upper-non-critical"
    PERF_UPPER_NON_RECOVERABLE = "upper-non-recoverable"
    POWER_DEGRADED = "degraded"
    POWER_ERROR = "error"
    POWER_FAILED = "failed"
    POWER_NOT_SUPPORTED = "not-supported"
    POWER_OFF = "off"
    POWER_OFFDUTY = "offduty"
    POWER_OFFLINE = "offline"
    POWER_OK = "ok"
    POWER_ON = "on"
    POWER_ONLINE = "online"
    POWER_POWER_SAVE = "power-save"
    POWER_TEST = "test"
    POWER_UNKNOWN = "unknown"
    PRESENCE_EMPTY = "empty"
    PRESENCE_EQUIPPED = "equipped"
    PRESENCE_EQUIPPED_DEPRECATED = "equipped-deprecated"
    PRESENCE_EQUIPPED_DISC_ERROR = "equipped-disc-error"
    PRESENCE_EQUIPPED_DISC_IN_PROGRESS = "equipped-disc-in-progress"
    PRESENCE_EQUIPPED_DISC_NOT_STARTED = "equipped-disc-not-started"
    PRESENCE_EQUIPPED_DISC_UNKNOWN = "equipped-disc-unknown"
    PRESENCE_EQUIPPED_IDENTITY_UNESTABLISHABLE = "equipped-identity-unestablishable"
    PRESENCE_EQUIPPED_NOT_PRIMARY = "equipped-not-primary"
    PRESENCE_EQUIPPED_SLAVE = "equipped-slave"
    PRESENCE_EQUIPPED_UNSUPPORTED = "equipped-unsupported"
    PRESENCE_EQUIPPED_WITH_MALFORMED_FRU = "equipped-with-malformed-fru"
    PRESENCE_INACCESSIBLE = "inaccessible"
    PRESENCE_MISMATCH = "mismatch"
    PRESENCE_MISMATCH_IDENTITY_UNESTABLISHABLE = "mismatch-identity-unestablishable"
    PRESENCE_MISMATCH_SLAVE = "mismatch-slave"
    PRESENCE_MISSING = "missing"
    PRESENCE_MISSING_SLAVE = "missing-slave"
    PRESENCE_NOT_SUPPORTED = "not-supported"
    PRESENCE_UNAUTHORIZED = "unauthorized"
    PRESENCE_UNKNOWN = "unknown"
    PURPOSE_CROSSLINK = "crosslink"
    PURPOSE_GENERAL = "general"
    PURPOSE_MANAGEMENT = "management"
    PURPOSE_OVERLAY = "overlay"
    PURPOSE_UNUSED = "unused"
    PURPOSE_UTILITY = "utility"
    SIDE_LEFT = "left"
    SIDE_RIGHT = "right"
    SWITCH_ID_A = "A"
    SWITCH_ID_B = "B"
    SWITCH_ID_NONE = "NONE"
    THERMAL_LOWER_CRITICAL = "lower-critical"
    THERMAL_LOWER_NON_CRITICAL = "lower-non-critical"
    THERMAL_LOWER_NON_RECOVERABLE = "lower-non-recoverable"
    THERMAL_NOT_SUPPORTED = "not-supported"
    THERMAL_OK = "ok"
    THERMAL_UNKNOWN = "unknown"
    THERMAL_UPPER_CRITICAL = "upper-critical"
    THERMAL_UPPER_NON_CRITICAL = "upper-non-critical"
    THERMAL_UPPER_NON_RECOVERABLE = "upper-non-recoverable"
    VOLTAGE_LOWER_CRITICAL = "lower-critical"
    VOLTAGE_LOWER_NON_CRITICAL = "lower-non-critical"
    VOLTAGE_LOWER_NON_RECOVERABLE = "lower-non-recoverable"
    VOLTAGE_NOT_SUPPORTED = "not-supported"
    VOLTAGE_OK = "ok"
    VOLTAGE_UNKNOWN = "unknown"
    VOLTAGE_UPPER_CRITICAL = "upper-critical"
    VOLTAGE_UPPER_NON_CRITICAL = "upper-non-critical"
    VOLTAGE_UPPER_NON_RECOVERABLE = "upper-non-recoverable"


class AdaptorHostIscsiIf(ManagedObject):
    """This is AdaptorHostIscsiIf class."""

    consts = AdaptorHostIscsiIfConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("AdaptorHostIscsiIf", "adaptorHostIscsiIf", "host-iscsi-[id]", VersionMeta.Version201m, "InputOutput", 0x3ff, [], ["admin", "ext-lan-config", "ext-lan-policy", "pn-equipment", "pn-maintenance", "read-only"], ['adaptorUnit'], ['adaptorIscsiProt', 'adaptorIscsiTargetIf', 'adaptorProtocolProfile', 'adaptorVlan', 'adaptorVnicStats', 'fabricNetflowIPv4Addr', 'faultInst', 'networkIfStats', 'vnicIPv4Dhcp', 'vnicIPv4Dns', 'vnicIPv4IscsiAddr', 'vnicIPv4PooledIscsiAddr', 'vnicIPv4StaticRoute', 'vnicIpV4MgmtPooledAddr', 'vnicIpV4PooledAddr', 'vnicIpV4ProfDerivedAddr', 'vnicIpV4StaticAddr'], ["Get"])

    prop_meta = {
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["disabled", "disabled-active", "disabled-passive", "enabled", "enabled-active", "enabled-passive", "reset-connectivity", "reset-connectivity-active", "reset-connectivity-passive"], []),
        "boot_dev": MoPropertyMeta("boot_dev", "bootDev", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["disabled", "enabled"], []),
        "cdn_name": MoPropertyMeta("cdn_name", "cdnName", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "chassis_id": MoPropertyMeta("chassis_id", "chassisId", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["N/A"], ["0-255"]),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version201m, MoPropertyMeta.INTERNAL, 0x8, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "discovery": MoPropertyMeta("discovery", "discovery", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["absent", "mis-connect", "missing", "new", "present", "un-initialized", "un-supported"], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "ep_dn": MoPropertyMeta("ep_dn", "epDn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "eth_ep_dn": MoPropertyMeta("eth_ep_dn", "ethEpDn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "flt_aggr": MoPropertyMeta("flt_aggr", "fltAggr", "ulong", VersionMeta.Version201m, MoPropertyMeta.INTERNAL, None, None, None, None, [], []),
        "host_visible": MoPropertyMeta("host_visible", "hostVisible", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["no", "os-dependent", "yes"], []),
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version201m, MoPropertyMeta.NAMING, 0x20, None, None, None, [], []),
        "if_role": MoPropertyMeta("if_role", "ifRole", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["diag", "fcoe-nas-storage", "fcoe-storage", "fcoe-uplink", "mgmt", "monitor", "nas-storage", "network", "network-fcoe-uplink", "server", "service", "storage", "unknown"], []),
        "if_type": MoPropertyMeta("if_type", "ifType", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["aggregation", "physical", "unknown", "virtual"], []),
        "initiator_name": MoPropertyMeta("initiator_name", "initiatorName", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "lc": MoPropertyMeta("lc", "lc", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["allocated", "available", "deallocated", "repurposed"], []),
        "link_state": MoPropertyMeta("link_state", "linkState", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["admin-down", "down", "error", "offline", "unallocated", "unavailable", "unknown", "up"], []),
        "locale": MoPropertyMeta("locale", "locale", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|server|chassis|internal|external),){0,5}(defaultValue|unknown|server|chassis|internal|external){0,1}""", [], []),
        "mac": MoPropertyMeta("mac", "mac", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, r"""(([0-9a-fA-F][0-9a-fA-F]:){5}([0-9a-fA-F][0-9a-fA-F]))|0""", [], []),
        "model": MoPropertyMeta("model", "model", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "oper_qualifier_reason": MoPropertyMeta("oper_qualifier_reason", "operQualifierReason", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["accessibility-problem", "auto-upgrade", "backplane-port-problem", "bios-post-timeout", "chassis-intrusion", "chassis-limit-exceeded", "config", "decomissioning", "degraded", "disabled", "discovery", "discovery-failed", "equipment-problem", "fabric-conn-problem", "fabric-unsupported-conn", "identify", "identity-unestablishable", "inoperable", "link-activate-blocked", "malformed-fru", "non-optimal", "non-optimal-severe", "not-supported", "operable", "peer-comm-problem", "performance-problem", "post-failure", "power-problem", "powered-off", "removed", "thermal-problem", "unknown", "unsupported-config", "upgrade-problem", "voltage-problem"], []),
        "operability": MoPropertyMeta("operability", "operability", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["accessibility-problem", "auto-upgrade", "backplane-port-problem", "bios-post-timeout", "chassis-intrusion", "chassis-limit-exceeded", "config", "decomissioning", "degraded", "disabled", "discovery", "discovery-failed", "equipment-problem", "fabric-conn-problem", "fabric-unsupported-conn", "identify", "identity-unestablishable", "inoperable", "link-activate-blocked", "malformed-fru", "non-optimal", "non-optimal-severe", "not-supported", "operable", "peer-comm-problem", "performance-problem", "post-failure", "power-problem", "powered-off", "removed", "thermal-problem", "unknown", "unsupported-config", "upgrade-problem", "voltage-problem"], []),
        "order": MoPropertyMeta("order", "order", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["unspecified"], ["0-65535"]),
        "original_mac": MoPropertyMeta("original_mac", "originalMac", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, r"""(([0-9a-fA-F][0-9a-fA-F]:){5}([0-9a-fA-F][0-9a-fA-F]))|0""", [], []),
        "pci_addr": MoPropertyMeta("pci_addr", "pciAddr", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "pci_func": MoPropertyMeta("pci_func", "pciFunc", "uint", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "pci_slot": MoPropertyMeta("pci_slot", "pciSlot", "uint", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-4294967295"]),
        "peer_chassis_id": MoPropertyMeta("peer_chassis_id", "peerChassisId", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["N/A"], ["0-255"]),
        "peer_dn": MoPropertyMeta("peer_dn", "peerDn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "peer_port_id": MoPropertyMeta("peer_port_id", "peerPortId", "uint", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "peer_slot_id": MoPropertyMeta("peer_slot_id", "peerSlotId", "uint", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "perf": MoPropertyMeta("perf", "perf", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["lower-critical", "lower-non-critical", "lower-non-recoverable", "not-supported", "ok", "unknown", "upper-critical", "upper-non-critical", "upper-non-recoverable"], []),
        "port_id": MoPropertyMeta("port_id", "portId", "uint", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "power": MoPropertyMeta("power", "power", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["degraded", "error", "failed", "not-supported", "off", "offduty", "offline", "ok", "on", "online", "power-save", "test", "unknown"], []),
        "presence": MoPropertyMeta("presence", "presence", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["empty", "equipped", "equipped-deprecated", "equipped-disc-error", "equipped-disc-in-progress", "equipped-disc-not-started", "equipped-disc-unknown", "equipped-identity-unestablishable", "equipped-not-primary", "equipped-slave", "equipped-unsupported", "equipped-with-malformed-fru", "inaccessible", "mismatch", "mismatch-identity-unestablishable", "mismatch-slave", "missing", "missing-slave", "not-supported", "unauthorized", "unknown"], []),
        "purpose": MoPropertyMeta("purpose", "purpose", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["crosslink", "general", "management", "overlay", "unused", "utility"], []),
        "revision": MoPropertyMeta("revision", "revision", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, 0x80, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "serial": MoPropertyMeta("serial", "serial", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "side": MoPropertyMeta("side", "side", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["left", "right"], []),
        "slot_id": MoPropertyMeta("slot_id", "slotId", "uint", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "switch_id": MoPropertyMeta("switch_id", "switchId", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["A", "B", "NONE"], []),
        "thermal": MoPropertyMeta("thermal", "thermal", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["lower-critical", "lower-non-critical", "lower-non-recoverable", "not-supported", "ok", "unknown", "upper-critical", "upper-non-critical", "upper-non-recoverable"], []),
        "transport": MoPropertyMeta("transport", "transport", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|ether|dce|fc),){0,4}(defaultValue|unknown|ether|dce|fc){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|lan|san|ipc),){0,4}(defaultValue|unknown|lan|san|ipc){0,1}""", [], []),
        "vendor": MoPropertyMeta("vendor", "vendor", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "vnic_dn": MoPropertyMeta("vnic_dn", "vnicDn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []),
        "vnic_name": MoPropertyMeta("vnic_name", "vnicName", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "voltage": MoPropertyMeta("voltage", "voltage", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, None, None, None, None, ["lower-critical", "lower-non-critical", "lower-non-recoverable", "not-supported", "ok", "unknown", "upper-critical", "upper-non-critical", "upper-non-recoverable"], []),
    }

    prop_map = {
        "adminState": "admin_state", 
        "bootDev": "boot_dev", 
        "cdnName": "cdn_name", 
        "chassisId": "chassis_id", 
        "childAction": "child_action", 
        "discovery": "discovery", 
        "dn": "dn", 
        "epDn": "ep_dn", 
        "ethEpDn": "eth_ep_dn", 
        "fltAggr": "flt_aggr", 
        "hostVisible": "host_visible", 
        "id": "id", 
        "ifRole": "if_role", 
        "ifType": "if_type", 
        "initiatorName": "initiator_name", 
        "lc": "lc", 
        "linkState": "link_state", 
        "locale": "locale", 
        "mac": "mac", 
        "model": "model", 
        "name": "name", 
        "operQualifierReason": "oper_qualifier_reason", 
        "operState": "oper_state", 
        "operability": "operability", 
        "order": "order", 
        "originalMac": "original_mac", 
        "pciAddr": "pci_addr", 
        "pciFunc": "pci_func", 
        "pciSlot": "pci_slot", 
        "peerChassisId": "peer_chassis_id", 
        "peerDn": "peer_dn", 
        "peerPortId": "peer_port_id", 
        "peerSlotId": "peer_slot_id", 
        "perf": "perf", 
        "portId": "port_id", 
        "power": "power", 
        "presence": "presence", 
        "purpose": "purpose", 
        "revision": "revision", 
        "rn": "rn", 
        "sacl": "sacl", 
        "serial": "serial", 
        "side": "side", 
        "slotId": "slot_id", 
        "status": "status", 
        "switchId": "switch_id", 
        "thermal": "thermal", 
        "transport": "transport", 
        "type": "type", 
        "vendor": "vendor", 
        "vnicDn": "vnic_dn", 
        "vnicName": "vnic_name", 
        "voltage": "voltage", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.admin_state = None
        self.boot_dev = None
        self.cdn_name = None
        self.chassis_id = None
        self.child_action = None
        self.discovery = None
        self.ep_dn = None
        self.eth_ep_dn = None
        self.flt_aggr = None
        self.host_visible = None
        self.if_role = None
        self.if_type = None
        self.initiator_name = None
        self.lc = None
        self.link_state = None
        self.locale = None
        self.mac = None
        self.model = None
        self.name = None
        self.oper_qualifier_reason = None
        self.oper_state = None
        self.operability = None
        self.order = None
        self.original_mac = None
        self.pci_addr = None
        self.pci_func = None
        self.pci_slot = None
        self.peer_chassis_id = None
        self.peer_dn = None
        self.peer_port_id = None
        self.peer_slot_id = None
        self.perf = None
        self.port_id = None
        self.power = None
        self.presence = None
        self.purpose = None
        self.revision = None
        self.sacl = None
        self.serial = None
        self.side = None
        self.slot_id = None
        self.status = None
        self.switch_id = None
        self.thermal = None
        self.transport = None
        self.type = None
        self.vendor = None
        self.vnic_dn = None
        self.vnic_name = None
        self.voltage = None

        ManagedObject.__init__(self, "AdaptorHostIscsiIf", parent_mo_or_dn, **kwargs)



# Copyright 2017 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from nose import SkipTest
from ..connection.info import custom_setup, custom_teardown, get_skip_msg
from ucsmsdk.ucshandle import UcsHandle


def test_serialize_handle():
    handle1 = custom_setup()
    if not handle1:
        msg = get_skip_msg()
        raise SkipTest(msg)

    frozen_handle = handle1.freeze()
    handle2 = UcsHandle.unfreeze(frozen_handle)
    custom_teardown(handle2)



"""This module contains the general information for LsbootIScsiImagePath ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class LsbootIScsiImagePathConsts:
    IP_ADDR_TYPE_IPV4 = "ipv4"
    IP_ADDR_TYPE_IPV6 = "ipv6"
    IP_ADDR_TYPE_NONE = "none"
    TYPE_PRIMARY = "primary"
    TYPE_SECONDARY = "secondary"


class LsbootIScsiImagePath(ManagedObject):
    """This is LsbootIScsiImagePath class."""

    consts = LsbootIScsiImagePathConsts()
    naming_props = set(['type'])

    mo_meta = MoMeta("LsbootIScsiImagePath", "lsbootIScsiImagePath", "path-[type]", VersionMeta.Version201m, "InputOutput", 0x1ff, [], ["admin", "ls-compute", "ls-config", "ls-config-policy", "ls-server", "ls-server-policy", "ls-storage", "ls-storage-policy"], ['lsbootIScsi'], ['lsbootUEFIBootParam'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version201m, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "i_scsi_vnic_name": MoPropertyMeta("i_scsi_vnic_name", "iSCSIVnicName", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "ip_addr_type": MoPropertyMeta("ip_addr_type", "ipAddrType", "string", VersionMeta.Version323a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["ipv4", "ipv6", "none"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version201m, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version201m, MoPropertyMeta.NAMING, 0x80, None, None, None, ["primary", "secondary"], []),
        "vnic_name": MoPropertyMeta("vnic_name", "vnicName", "string", VersionMeta.Version201m, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "iSCSIVnicName": "i_scsi_vnic_name", 
        "ipAddrType": "ip_addr_type", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "type": "type", 
        "vnicName": "vnic_name", 
    }

    def __init__(self, parent_mo_or_dn, type, **kwargs):
        self._dirty_mask = 0
        self.type = type
        self.child_action = None
        self.i_scsi_vnic_name = None
        self.ip_addr_type = None
        self.sacl = None
        self.status = None
        self.vnic_name = None

        ManagedObject.__init__(self, "LsbootIScsiImagePath", parent_mo_or_dn, **kwargs)
